/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 * 
 * $Id: BasicClassIdentifier.java,v 1.1.1.1 2006/01/31 09:13:26 gxie Exp $
 */

package org.eclipse.eodm.owl.reasoner.structural;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import org.eclipse.eodm.owl.IntersectionClass;
import org.eclipse.eodm.owl.OWLClass;
import org.eclipse.eodm.owl.OWLFactory;
import org.eclipse.eodm.owl.UnionClass;

/**
 * BasicClassIdentifier TODO Please add comments here.
 */
public class BasicClassIdentifier {
    public BasicClassIdentifier(RDFPropertyGraph pGraph) {
        this.pGraph = pGraph;
    }

    /**
     * Get the ID for the specified class expression.
     * 
     * @param c
     *            The class expression
     * @param doNormalizationFirst
     *            If this is set true, the class expression will be normalized
     *            first.
     * @param create
     *            If this is set true, a new ID will be given to the class
     *            expression if it doesn't exist in the identifier.
     * @return The ID of the class expression. If the class expression doesn't
     *         exist in the identifier and create is set false, -1 will be
     *         returned.
     */
    public int getOWLClassID(OWLClass c, boolean doNormalizationFirst,
            boolean create) {
        if (doNormalizationFirst) {
            c = ReasonerUtils.getForm(pGraph, c, 0);
        }
        for (int i = classList.size() - 1; i >= 0; i--) {
            if (ReasonerUtils.basicIsEquivalentClass(pGraph,
                    (OWLClass) classList.get(i), c)) {
                return i;
            }
        }
        if (create) {
            classList.add(ReasonerUtils.cloneClass(c));
            return classList.size() - 1;
        } else {
            return -1;
        }
    }

    public OWLClass getOWLClass(int id) {
        if (id < 0 || id >= classList.size()) {
            return null;
        } else {
            return ReasonerUtils.cloneClass((OWLClass) classList.get(id));
        }
    }

    public OWLClass buildUnionClass(Object o) {
        if (o instanceof Collection) {
            if (((Collection) o).size() == 0) {
                return ReasonerUtils.cloneClass(ReasonerUtils.nothing);
            }
            if (((Collection) o).size() == 1) {
                return buildIntersectionClass(((Collection) o).iterator()
                        .next());
            }
            UnionClass c = OWLFactory.eINSTANCE.createUnionClass();
            Iterator iter = ((Collection) o).iterator();
            while (iter.hasNext()) {
                c.getOWLUnionOf().add(buildIntersectionClass(iter.next()));
            }
            return c;
        } else if (o instanceof Integer) {
            return getOWLClass(((Integer) o).intValue());
        } else {
            throw new IllegalArgumentException();
        }
    }

    public OWLClass buildIntersectionClass(Object o) {
        if (o instanceof Collection) {
            if (((Collection) o).size() == 0) {
                return ReasonerUtils.cloneClass(ReasonerUtils.thing);
            }
            if (((Collection) o).size() == 1) {
                return buildUnionClass(((Collection) o).iterator().next());
            }
            IntersectionClass c = OWLFactory.eINSTANCE
                    .createIntersectionClass();
            Iterator iter = ((Collection) o).iterator();
            while (iter.hasNext()) {
                c.getOWLIntersectionOf().add(buildUnionClass(iter.next()));
            }
            return c;
        } else if (o instanceof Integer) {
            return getOWLClass(((Integer) o).intValue());
        } else {
            throw new IllegalArgumentException();
        }
    }

    public int getClassCount() {
        return classList.size();
    }

    private ArrayList classList = new ArrayList();

    private RDFPropertyGraph pGraph;
}
