/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 * 
 * $Id: OWLModelDocMapping.java,v 1.1.1.1 2006/01/31 09:13:26 gxie Exp $
 */

package org.eclipse.eodm.owl.resource.parser;

import java.util.List;
import java.util.Map;

import org.eclipse.eodm.owl.resource.parser.impl.ReferenceRecorder;
import org.eclipse.eodm.rdf.resource.parser.element.RDFTriple;
import org.eclipse.eodm.rdfs.RDFList;

/**
 * OWLModelDocMapping An ontology model can include multiple documents.
 */
public interface OWLModelDocMapping {
    /**
     * Set the OWL ontology model.
     * 
     * @param model
     *            the OWL ontology model
     */
    void setModel(OWLOntoModel model);

    /**
     * Get the OWL ontology model
     * 
     * @return the OWL ontology model
     */
    OWLOntoModel getModel();

    /**
     * Add an OWL document related to the OWL ontology model.
     * 
     * @param doc
     *            the document
     */
    void addDoc(OWLDocument doc);

    /**
     * Get the OWL Document by local URI.
     * 
     * @param uri
     *            the document local uri
     * @return the document
     */
    OWLDocument getDocByLURI(String lURI);

    /**
     * Get the OWL Document by public URI.
     * 
     * @param uri
     *            the document public uri
     * @return the document
     */
    OWLDocument getDocByPURI(String pURI);

    /**
     * Get all the documents.
     * 
     * @return all the documents
     */
    List getDocs();

    /**
     * Add an ambiguous restriction.
     * 
     * @param id
     *            the restriction id
     */
    void addRestriction(String id);

    /**
     * Check whether the model contains the restriction specified by id.
     * 
     * @param id
     *            the restriction id
     * @return true if the model contains the restriction
     */
    boolean containsRestriction(String id);

    /**
     * Get all the restrictions.
     * 
     * @return all the restrictions
     */
    Map getRestrictions();

    /**
     * Add an RDF List to the model.
     * 
     * @param list
     *            the list to be added
     */
    void addList(RDFList list);

    /**
     * Get the RDF List specified by id.
     * 
     * @param id
     *            the list id
     * @return the RDF List
     */
    RDFList getList(String id);

    /**
     * Get all the lists.
     * 
     * @return all the lists
     */
    Map getLists();

    /**
     * Add imported URI.
     * 
     * @param impURI
     */
    void addImpURI(String impURI);

    /**
     * Get all the imported uris
     * 
     * @return all the imported uris
     */
    Map getImpURIs();

    /**
     * Add a unparsed triple to the temporary storage
     * 
     * @param triple
     *            the RDF Triple
     */
    void addUnparsedTriple(RDFTriple triple);

    /**
     * Get all unparsed triples.
     * 
     * @return all unparsed triples
     */
    List getUnparsedTriples();

    /**
     * Add an axiom which relates to RDFSClass.
     * 
     * @param axiom
     *            the axiom which relates to RDFSClass
     */
    void addReference(ReferenceRecorder axiom);

    /**
     * Get all the axioms related to RDFSClass
     * 
     * @return all the axioms related to RDFSClass
     */
    List getReferences();

    /**
     * Clear all resources contained by the mapping.
     */
    void clearResources();
}