/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 * 
 * $Id: OWLTypeConstants.java,v 1.1.1.1 2006/01/31 09:13:26 gxie Exp $
 */

package org.eclipse.eodm.owl.resource.parser.impl;

import org.eclipse.eodm.owl.vocabulary.OWL;

/**
 * OWLTypeConstants
 */
public final class OWLTypeConstants {
    //1. owl:Ontology
    public static final int OWL_TYPE_ONTOLOGY = 1;

    //2. owl:Class
    public static final int OWL_TYPE_CLASS = 2;

    //3. owl:DeprecatedClass
    public static final int OWL_TYPE_DEPRECATED_CLASS = 3;

    //4. owl:Restriction
    public static final int OWL_TYPE_RESTRICTION = 4;

    //5. owl:ObjectProperty
    public static final int OWL_TYPE_OBJECT_PROPERTY = 5;

    //6. owl:DatatypeProperty
    public static final int OWL_TYPE_DATATYPE_PROPERTY = 6;

    //7. owl:DeprecatedProperty
    public static final int OWL_TYPE_DEPRECATED_PROPERTY = 7;

    //8. owl:FunctionalProperty (ObjectProperty || DatatypeProperty)
    public static final int OWL_TYPE_FUNCTIONAL_PROPERTY = 8;

    //9. owl:InverseFunctionalProperty (ObjectProperty)
    public static final int OWL_TYPE_INVERSE_FUNCTIONAL_PROPERTY = 9;

    //10. owl:SymmetricProperty (ObjectProperty)
    public static final int OWL_TYPE_SYMMETRIC_PROPERTY = 10;

    //11. owl:TransitiveProperty (ObjectProperty)
    public static final int OWL_TYPE_TRANSITIVE_PROPERTY = 11;

    //12. owl:Thing (Individual)
    public static final int OWL_TYPE_THING = 12;

    //13. owl:Nothing
    public static final int OWL_TYPE_NOTHING = 13;

    //14. owl:AllDifferent
    public static final int OWL_TYPE_ALL_DIFFERENT = 14;

    //15. owl:DataRange
    public static final int OWL_TYPE_DATARANGE = 15;

    //16. owl:OntologyProperty
    public static final int OWL_TYPE_ONTOLOGY_PROPERTY = 16;

    //17. owl:AnnotationProperty
    public static final int OWL_TYPE_ANNOTATION_PROPERTY = 17;

    //-1. unknown type
    public static final int OWL_TYPE_UNKNOWN = -1;

    /**
     * Get type constant by the rdf:type triple's object. 1. OWL typed elements:
     * <br>
     * (1) http://www.w3.org/2002/07/owl#Ontology 1 (2)
     * http://www.w3.org/2002/07/owl#Class 2 (3)
     * http://www.w3.org/2002/07/owl#DeprecatedClass 3 (4)
     * http://www.w3.org/2002/07/owl#Restriction 4 (5)
     * http://www.w3.org/2002/07/owl#ObjectProperty 5 (6)
     * http://www.w3.org/2002/07/owl#DatatypeProperty 6 (7)
     * http://www.w3.org/2002/07/owl#DeprecatedProperty 7 (8)
     * http://www.w3.org/2002/07/owl#FunctionalProperty (ObjectProperty ||
     * DatatypeProperty) 8 (9)
     * http://www.w3.org/2002/07/owl#InverseFunctionalProperty (ObjectProperty)
     * 9 (10) http://www.w3.org/2002/07/owl#SymmetricProperty (ObjectProperty)
     * 10 (11) http://www.w3.org/2002/07/owl#TransitiveProperty (ObjectProperty)
     * 11 (12) http://www.w3.org/2002/07/owl#Thing 12 (13)
     * http://www.w3.org/2002/07/owl#Nothing 13 (14)
     * http://www.w3.org/2002/07/owl#AllDifferent 14 (15)
     * http://www.w3.org/2002/07/owl#DataRange 15 (16)
     * http://www.w3.org/2002/07/owl#OntologyProperty 16 (17)
     * http://www.w3.org/2002/07/owl#AnnotationProperty 17
     * <p>
     * 2. RDF(S) typed elements: <br>
     * 
     * @see org.eclipse.eodm.owl.resource.parser.impl.RDFTypeConstants rdf:Seq
     *      rdf:Bag rdf:Alt rdf:Statement rdf:Property (*) rdf:XMLLiteral (X)
     *      rdf:List rdfs:Resource (*) rdfs:Class (*) rdfs:Literal (X)
     *      rdfs:Datatype rdfs:Container (*) rdfs:ContainerMembershipProperty
     *      (*)
     * @param uri
     *            the unified resource indentifier
     * @return the type constant
     */
    public static int getOWLTypeByURI(String uri) {
        if (null == uri || "".equals(uri))
            return OWL_TYPE_UNKNOWN;

        if (uri.equals(OWL.ONTOLOGY_URI))
            return OWL_TYPE_ONTOLOGY;
        if (uri.equals(OWL.CLASS_URI))
            return OWL_TYPE_CLASS;
        if (uri.equals(OWL.DEPRECATED_CLASS_URI))
            return OWL_TYPE_DEPRECATED_CLASS;
        if (uri.equals(OWL.RESTRICTION_URI))
            return OWL_TYPE_RESTRICTION;
        if (uri.equals(OWL.OBJECT_PROPERTY_URI))
            return OWL_TYPE_OBJECT_PROPERTY;
        if (uri.equals(OWL.DATATYPE_PROPERTY_URI))
            return OWL_TYPE_DATATYPE_PROPERTY;
        if (uri.equals(OWL.DEPRECATED_PROPERTY_URI))
            return OWL_TYPE_DEPRECATED_PROPERTY;
        if (uri.equals(OWL.FUNCTIONAL_PROPERTY_URI))
            return OWL_TYPE_FUNCTIONAL_PROPERTY;
        if (uri.equals(OWL.INVERSE_FUNCTIONAL_PROPERTY_URI))
            return OWL_TYPE_INVERSE_FUNCTIONAL_PROPERTY;
        if (uri.equals(OWL.SYMMETRIC_PROPERTY_URI))
            return OWL_TYPE_SYMMETRIC_PROPERTY;
        if (uri.equals(OWL.TRANSITIVE_PROPERTY_URI))
            return OWL_TYPE_TRANSITIVE_PROPERTY;
        if (uri.equals(OWL.THING_URI))
            return OWL_TYPE_THING;
        if (uri.equals(OWL.NOTHING_URI))
            return OWL_TYPE_NOTHING;
        if (uri.equals(OWL.ALL_DIFFERENT_URI))
            return OWL_TYPE_ALL_DIFFERENT;
        if (uri.equals(OWL.DATA_RANGE_URI))
            return OWL_TYPE_DATARANGE;
        if (uri.equals(OWL.ONTOLOGY_PROPERTY_URI))
            return OWL_TYPE_ONTOLOGY_PROPERTY;
        if (uri.equals(OWL.ANNOTATION_PROPERTY_URI))
            return OWL_TYPE_ANNOTATION_PROPERTY;

        return OWL_TYPE_UNKNOWN;
    }

    private OWLTypeConstants() {
    }
}