/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 * 
 * $Id: OWLTypedElementGenerator.java,v 1.1.1.1 2006/01/31 09:13:26 gxie Exp $
 */

package org.eclipse.eodm.owl.resource.parser.impl;

import org.eclipse.eodm.owl.AllValuesFromRestriction;
import org.eclipse.eodm.owl.CardinalityRestriction;
import org.eclipse.eodm.owl.ComplementClass;
import org.eclipse.eodm.owl.DatatypeSlot;
import org.eclipse.eodm.owl.EnumeratedClass;
import org.eclipse.eodm.owl.HasValueRestriction;
import org.eclipse.eodm.owl.Individual;
import org.eclipse.eodm.owl.IntersectionClass;
import org.eclipse.eodm.owl.MaxCardinalityRestriction;
import org.eclipse.eodm.owl.MinCardinalityRestriction;
import org.eclipse.eodm.owl.OWLAllDifferent;
import org.eclipse.eodm.owl.OWLAnnotationProperty;
import org.eclipse.eodm.owl.OWLClass;
import org.eclipse.eodm.owl.OWLDataRange;
import org.eclipse.eodm.owl.OWLDatatypeProperty;
import org.eclipse.eodm.owl.OWLFactory;
import org.eclipse.eodm.owl.OWLObjectProperty;
import org.eclipse.eodm.owl.OWLOntology;
import org.eclipse.eodm.owl.OWLOntologyProperty;
import org.eclipse.eodm.owl.ObjectSlot;
import org.eclipse.eodm.owl.SomeValuesFromRestriction;
import org.eclipse.eodm.owl.UnionClass;
import org.eclipse.eodm.rdfs.Namespace;

/**
 * OWLTypedElementGenerator
 */
public final class OWLTypedElementGenerator {
    private OWLTypedElementGenerator() {
    }

    /** The single instance of OWLTypeGenerator */
    public static final OWLTypedElementGenerator _INSTANCE = new OWLTypedElementGenerator();

    /**
     * Create an OWL ontology with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created ontology
     */
    public OWLOntology createOntology(Namespace namespace, String localName) {
        OWLOntology ontology = OWLFactory.eINSTANCE.createOWLOntology();
        ontology.setNamespace(namespace);
        ontology.setLocalName(localName);
        return ontology;
    }

    /**
     * Create an OWL class with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created clsss
     */
    public OWLClass createClass(Namespace namespace, String localName) {
        OWLClass cls = OWLFactory.eINSTANCE.createOWLClass();
        cls.setNamespace(namespace);
        cls.setLocalName(localName);
        return cls;
    }

    /**
     * Create an OWL enumeration class the with namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created enumeration class
     */
    public EnumeratedClass createEnumeratedClass(Namespace namespace,
            String localName) {
        EnumeratedClass cls = OWLFactory.eINSTANCE.createEnumeratedClass();
        cls.setNamespace(namespace);
        cls.setLocalName(localName);
        return cls;
    }

    /**
     * Create an OWL union class with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created union class
     */
    public UnionClass createUnionClass(Namespace namespace, String localName) {
        UnionClass cls = OWLFactory.eINSTANCE.createUnionClass();
        cls.setNamespace(namespace);
        cls.setLocalName(localName);
        return cls;
    }

    /**
     * Create an OWL intersection class with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created intersection class
     */
    public IntersectionClass createIntersectionClass(Namespace namespace,
            String localName) {
        IntersectionClass cls = OWLFactory.eINSTANCE.createIntersectionClass();
        cls.setNamespace(namespace);
        cls.setLocalName(localName);
        return cls;
    }

    /**
     * Create an OWL complement class with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created complement class
     */
    public ComplementClass createComplementClass(Namespace namespace,
            String localName) {
        ComplementClass cls = OWLFactory.eINSTANCE.createComplementClass();
        cls.setNamespace(namespace);
        cls.setLocalName(localName);
        return cls;
    }

    /**
     * Create an OWL deprecated class with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created deprecated class
     */
    public OWLClass createDeprecatedClass(Namespace namespace, String localName) {
        OWLClass cls = createClass(namespace, localName);
        cls.setDeprecated(Boolean.TRUE);
        return cls;
    }

    /**
     * Create an OWL hasValue restriction with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created hasValue restriction
     */
    public HasValueRestriction createHasValueRestriction(Namespace namespace,
            String localName) {
        HasValueRestriction restriction = OWLFactory.eINSTANCE
                .createHasValueRestriction();
        restriction.setNamespace(namespace);
        restriction.setLocalName(localName);
        return restriction;
    }

    /**
     * Create an OWL allValuesFrom restriction with the namespace and local
     * name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created allValuesFrom restriction
     */
    public AllValuesFromRestriction createAllValuesFromRestriction(
            Namespace namespace, String localName) {
        AllValuesFromRestriction restriction = OWLFactory.eINSTANCE
                .createAllValuesFromRestriction();
        restriction.setNamespace(namespace);
        restriction.setLocalName(localName);
        return restriction;
    }

    /**
     * Create an OWL someValuesFrom restriction with the namespace and local
     * name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created someValuesFrom restriction
     */
    public SomeValuesFromRestriction createSomeValuesFromRestriction(
            Namespace namespace, String localName) {
        SomeValuesFromRestriction restriction = OWLFactory.eINSTANCE
                .createSomeValuesFromRestriction();
        restriction.setNamespace(namespace);
        restriction.setLocalName(localName);
        return restriction;
    }

    /**
     * Create an OWL cardinality restriction with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created cardinality restriction
     */
    public CardinalityRestriction createCardinalityRestriction(
            Namespace namespace, String localName) {
        CardinalityRestriction restriction = OWLFactory.eINSTANCE
                .createCardinalityRestriction();
        restriction.setNamespace(namespace);
        restriction.setLocalName(localName);
        return restriction;
    }

    /**
     * Create an OWL maxCardinality restriction with the namespace and local
     * name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created maxCardinality restriction
     */
    public MaxCardinalityRestriction createMaxCardinalityRestriction(
            Namespace namespace, String localName) {
        MaxCardinalityRestriction restriction = OWLFactory.eINSTANCE
                .createMaxCardinalityRestriction();
        restriction.setNamespace(namespace);
        restriction.setLocalName(localName);
        return restriction;
    }

    /**
     * Create an OWL minCardinality restriction with the namespace and local
     * name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created minCardinality restriction
     */
    public MinCardinalityRestriction createMinCardinalityRestriction(
            Namespace namespace, String localName) {
        MinCardinalityRestriction restriction = OWLFactory.eINSTANCE
                .createMinCardinalityRestriction();
        restriction.setNamespace(namespace);
        restriction.setLocalName(localName);
        return restriction;
    }

    /**
     * Create an OWL object property with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created object property
     */
    public OWLObjectProperty createObjectProperty(Namespace namespace,
            String localName) {
        OWLObjectProperty property = OWLFactory.eINSTANCE
                .createOWLObjectProperty();
        property.setNamespace(namespace);
        property.setLocalName(localName);
        return property;
    }

    /**
     * Create an OWL datatype property with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created datatype property
     */
    public OWLDatatypeProperty createDatatypeProperty(Namespace namespace,
            String localName) {
        OWLDatatypeProperty property = OWLFactory.eINSTANCE
                .createOWLDatatypeProperty();
        property.setNamespace(namespace);
        property.setLocalName(localName);
        return property;
    }

    /**
     * Create an individual with the namespace and local name. owl:Thing
     * construct.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created individual
     */
    public Individual createIndividual(Namespace namespace, String localName) {
        Individual individual = OWLFactory.eINSTANCE.createIndividual();
        individual.setNamespace(namespace);
        individual.setLocalName(localName);
        return individual;
    }

    /**
     * owl:Nothing construct.
     * 
     * @deprecated No instance of owl:Nothing class is created.
     * @return null
     */
    public Individual createNullIndividual() {
        return null;
    }

    /**
     * Create an OWL AllDifferent.
     * 
     * @return the OWLAllDifferent instance
     */
    public OWLAllDifferent createAllDifferent() {
        return OWLFactory.eINSTANCE.createOWLAllDifferent();
    }

    /**
     * Create an OWL data range with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created data range
     */
    public OWLDataRange createDataRange(Namespace namespace, String localName) {
        OWLDataRange dataRange = OWLFactory.eINSTANCE.createOWLDataRange();
        dataRange.setNamespace(namespace);
        dataRange.setLocalName(localName);
        return dataRange;
    }

    /**
     * Create an OWL ontology property with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created ontology property
     */
    public OWLOntologyProperty createOntologyProperty(Namespace namespace,
            String localName) {
        OWLOntologyProperty ontoProperty = OWLFactory.eINSTANCE
                .createOWLOntologyProperty();
        ontoProperty.setNamespace(namespace);
        ontoProperty.setLocalName(localName);
        return ontoProperty;
    }

    /**
     * Create an OWL annotation property with the namespace and local name.
     * 
     * @param namespace
     *            the namespace
     * @param localName
     *            the local name
     * @return the created annotation property
     */
    public OWLAnnotationProperty createAnnotationProperty(Namespace namespace,
            String localName) {
        OWLAnnotationProperty annoProperty = OWLFactory.eINSTANCE
                .createOWLAnnotationProperty();
        annoProperty.setNamespace(namespace);
        annoProperty.setLocalName(localName);
        return annoProperty;
    }

    /**
     * Create an OWL Object Slot.
     * 
     * @return the created Object Slot
     */
    public ObjectSlot createObjectSlot() {
        return OWLFactory.eINSTANCE.createObjectSlot();
    }

    /**
     * Create an OWL Datatype Slot.
     * 
     * @return the created Datatype Slot
     */
    public DatatypeSlot createDatatypeSlot() {
        return OWLFactory.eINSTANCE.createDatatypeSlot();
    }
}