/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 * 
 * $Id: RDFParserResultHandler.java,v 1.1.1.1.4.1 2007/04/28 09:54:14 lzhang Exp $
 */

package org.eclipse.eodm.owl.resource.parser.impl;

import org.eclipse.eodm.rdf.resource.parser.NamespaceHandler;
import org.eclipse.eodm.rdf.resource.parser.StatementHandler;
import org.eclipse.eodm.rdf.resource.parser.element.RDFResourceElement;
import org.eclipse.eodm.rdf.resource.parser.element.RDFValue;
import org.eclipse.eodm.rdf.resource.parser.element.URIReference;

/**
 * RDFParserResultHandler - RDF Parser result handler.
 *  
 */
public class RDFParserResultHandler implements StatementHandler,
        NamespaceHandler {
    RDFParserTripleAnalyser analyser = null;

    /**
     * Constructs an RDF parser result handler.
     */
    public RDFParserResultHandler(RDFParserTripleAnalyser analyser) {
        super();
        this.analyser = analyser;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.rdfs.resource.parser.StatementHandler#exportStatement(org.eclipse.rdfs.parser.element.RDFResource,
     *      org.eclipse.rdfs.parser.element.URIReference,
     *      org.eclipse.rdfs.parser.element.RDFValue)
     */
    public void exportStatement(RDFResourceElement subject,
            URIReference predicate, RDFValue object) {
        analyser.analyzeStatement(subject, predicate, object);
        //System.out.println(subject.getFullURI()+ ":" +predicate.getFullURI()+ ":" +object.toString()) ;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.rdfs.resource.parser.StatementHandler#setSeparateExport(boolean)
     */
    public void setSeparateExport(boolean exportSeparate) {
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.rdfs.resource.parser.StatementHandler#isSeparateExport()
     */
    public boolean isSeparateExport() {
        return false;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.rdfs.resource.parser.NamespaceHandler#exportNamespace(java.lang.String,
     *      java.lang.String)
     */
    public void exportNamespace(String abbr, String fullURI) {
        analyser.handleNamespace(abbr, fullURI);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.rdfs.resource.parser.StatementHandler#exportReification(org.eclipse.rdfs.resource.parser.element.RDFResource,
     *      org.eclipse.rdfs.resource.parser.element.RDFResource,
     *      org.eclipse.rdfs.resource.parser.element.URIReference,
     *      org.eclipse.rdfs.resource.parser.element.RDFValue)
     */
    public void exportReification(RDFResourceElement reifyNode,
            RDFResourceElement subject, URIReference predicate, RDFValue object) {

    }
}