/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 * 
 * $Id: RDFTypedElementGenerator.java,v 1.1.1.1 2006/01/31 09:13:26 gxie Exp $
 */

package org.eclipse.eodm.owl.resource.parser.impl;

import org.eclipse.eodm.rdfs.Namespace;
import org.eclipse.eodm.rdfs.RDFAlt;
import org.eclipse.eodm.rdfs.RDFBag;
import org.eclipse.eodm.rdfs.RDFList;
import org.eclipse.eodm.rdfs.RDFSDatatype;
import org.eclipse.eodm.rdfs.RDFSFactory;
import org.eclipse.eodm.rdfs.RDFSeq;
import org.eclipse.eodm.rdfs.RDFStatement;

/**
 * RDFTypedElementGenerator All the methods to create RDF Type Elements.
 */
public final class RDFTypedElementGenerator {
    private RDFTypedElementGenerator() {
    }

    /** The single instance of RDFTypeGenerator */
    public static final RDFTypedElementGenerator _INSTANCE = new RDFTypedElementGenerator();

    public Namespace createNamespace(String name, String uri) {
        Namespace namespace = RDFSFactory.eINSTANCE.createNamespace();
        namespace.setName(name);
        if (namespace.getName() == null || namespace.getName().equals("")){            
            String n=NSNameGenerator._INSTANCE.getNextKey();            
            namespace.setName(n);
        }
        namespace.setURI(uri);
        return namespace;
    }

    /** Create an rdf Alt container */
    public RDFAlt createAlt(Namespace namespace, String localName) {
        RDFAlt alt = RDFSFactory.eINSTANCE.createRDFAlt();
        alt.setNamespace(namespace);
        alt.setLocalName(localName);
        return alt;
    }

    /** Create an rdf Bag container */
    public RDFBag createBag(Namespace namespace, String localName) {
        RDFBag bag = RDFSFactory.eINSTANCE.createRDFBag();
        bag.setNamespace(namespace);
        bag.setLocalName(localName);
        return bag;
    }

    /** Create an rdf Seq container */
    public RDFSeq createSeq(Namespace namespace, String localName) {
        RDFSeq seq = RDFSFactory.eINSTANCE.createRDFSeq();
        seq.setNamespace(namespace);
        seq.setLocalName(localName);
        return seq;
    }

    /** Create an rdf Statement */
    public RDFStatement createStatement(Namespace namespace, String localName) {
        RDFStatement statement = RDFSFactory.eINSTANCE.createRDFStatement();
        statement.setNamespace(namespace);
        statement.setLocalName(localName);
        return statement;
    }

    /** Create an rdf List */
    public RDFList createList(Namespace namespace, String localName) {
        RDFList list = RDFSFactory.eINSTANCE.createRDFList();
        list.setNamespace(namespace);
        list.setLocalName(localName);
        return list;
    }

    /** Create an rdfs Datatype */
    public RDFSDatatype createDatatype(Namespace namespace, String localName) {
        RDFSDatatype datatype = RDFSFactory.eINSTANCE.createRDFSDatatype();
        datatype.setNamespace(namespace);
        datatype.setLocalName(localName);
        return datatype;
    }
}