/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 * 
 * $Id: OWL2ECoreTransformer.java,v 1.2.6.2 2007/07/26 11:10:28 lzhang Exp $
 */
package org.eclipse.eodm.owl.transformer.ecore;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Properties;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EAnnotation;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EClassifier;
import org.eclipse.emf.ecore.EDataType;
import org.eclipse.emf.ecore.EEnum;
import org.eclipse.emf.ecore.EEnumLiteral;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.EReference;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.emf.ecore.EcoreFactory;
import org.eclipse.emf.ecore.EcorePackage;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
import org.eclipse.emf.ecore.xmi.impl.EcoreResourceFactoryImpl;
import org.eclipse.eodm.owl.CardinalityRestriction;
import org.eclipse.eodm.owl.EnumeratedClass;
import org.eclipse.eodm.owl.MaxCardinalityRestriction;
import org.eclipse.eodm.owl.MinCardinalityRestriction;
import org.eclipse.eodm.owl.OWLClass;
import org.eclipse.eodm.owl.OWLDataRange;
import org.eclipse.eodm.owl.OWLObjectProperty;
import org.eclipse.eodm.owl.OWLOntology;
import org.eclipse.eodm.owl.Property;
import org.eclipse.eodm.owl.reasoner.OWLTaxonomyReasoner;
import org.eclipse.eodm.owl.reasoner.structural.StructuralReasonerFactory;
import org.eclipse.eodm.owl.resource.parser.OWLDocument;
import org.eclipse.eodm.owl.resource.parser.OWLParser;
import org.eclipse.eodm.owl.resource.parser.impl.OWLDocumentImpl;
import org.eclipse.eodm.owl.resource.parser.impl.OWLParserImpl;
import org.eclipse.eodm.owl.transformer.OWLTransformationException;
import org.eclipse.eodm.rdfs.PlainLiteral;
import org.eclipse.eodm.rdfs.RDFSClass;
import org.eclipse.eodm.rdfs.RDFSDatatype;
import org.eclipse.eodm.rdfs.RDFSLiteral;
import org.eclipse.eodm.rdfs.RDFSResource;
import org.eclipse.eodm.rdfs.vocabulary.RDF;
import org.eclipse.eodm.rdfs.vocabulary.RDFS;


public class OWL2ECoreTransformer {


    public OWL2ECoreTransformer()
    {
    	
    }

    public OWL2ECoreTransformer(String configFilePath) throws OWLTransformationException {
    	loadProperties(configFilePath);
    }

	/**
	 * Translate function Translate the input owl file to target ecore file.
	 * 
	 * @param input
	 *            owl file
	 * @throws OWLTransformationException
	 */
	public void convertOWL2Ecore(String input) throws OWLTransformationException {
		convertOWL2Ecore(input, null);
		
		//OWLOntology ontology = loadOWLModel(input);
	}

	/**
	 * Translate function Translate the input owl file to target ecore file.
	 * 
	 * @param input
	 *            owl file
	 * @param output
	 *            target ecore file
	 * @throws OWLTransformationException
	 */
	public void convertOWL2Ecore(String inputFilePath, String outputFilePath)
			throws OWLTransformationException {
		OWLOntology ontology = loadOWLModel(inputFilePath);
		EPackage epkg = owl2Ecore(ontology);
		
		try {
			if(outputFilePath==null) {
				int index = inputFilePath.lastIndexOf(".owl");
				outputFilePath = (index!=-1) ? inputFilePath.substring(0, index) + ".ecore" : inputFilePath + ".ecore";
			}
			
			saveEcore(epkg, outputFilePath);

			
		} catch(Exception e){
			throw new OWLTransformationException(e.getMessage());
		}
	}
	
	/*
	 * convert owl to ecore
	 * 
	 * @param ontology
	 * @throws OWLTransformationException
	 */
	private EPackage owl2Ecore(OWLOntology ontology) throws OWLTransformationException {
		initialize(ontology);
		
		EPackage epackage = EcoreFactory.eINSTANCE.createEPackage();
		epackage.setName(ontology.getLocalName());
		
		// OWL -> Ecore
		List classList = ontology.getResourceList(RDFSClass.class);

		for(Iterator itCls = classList.iterator();itCls.hasNext();){
			RDFSClass rclass = (RDFSClass) itCls.next();
			
			// filter out Restriction anonymous owlclass
			if (rclass.getNamespace().getURI().equals(RDFS.BNODE_NAMESPACE))
				continue;
			
            // fitler out owl:thing
            if(rclass.getURI().equals(OWL_THING) && rclass.getSubClass().isEmpty() ) {
                continue;
            }
            
            EClassifier eclass = owl2eclassifier(rclass); 
            if( !(eclass instanceof EDataType) || eclass instanceof EEnum){
            	// get rid of EString, EInt...
            	epackage.getEClassifiers().add(eclass);
            }
			
			
            if(eclass==null) 
            	continue;
            
            if(eclass instanceof EClass) {
            	OWLClass oclass = (OWLClass)rclass;
            	// RDFSSubClassOf -> EClass.eSuperType
				for (Iterator itSuper = getDirectParent(oclass).iterator();itSuper.hasNext();) {
					OWLClass superClass = (OWLClass) itSuper.next();
					
					if( superClass != oclass) {
					    EClass eSuperClass = (EClass)owl2eclassifier(superClass);
					    
					    // check whether eclass if father of eSuperClass
					    if ( eSuperClass.getESuperTypes().contains(eclass) ) {
					        eSuperClass.getESuperTypes().remove(eclass);
					        
					        EAnnotation annotation1 = EcoreFactory.eINSTANCE.createEAnnotation();
					        annotation1.setSource("The " + eclass.getName() + " class is equivalent with " + eSuperClass.getName() + ".");
					        eclass.getEAnnotations().add(annotation1);
					        
					        EAnnotation annotation2 = EcoreFactory.eINSTANCE.createEAnnotation();
					        annotation2.setSource("The " + eSuperClass.getName() + " class is equivalent with " + eclass.getName() + ".");
					        eSuperClass.getEAnnotations().add(annotation2);
					    } else {
					        ((EClass)eclass).getESuperTypes().add(eSuperClass);
					    }
					}
				}
				
				List multiplicity = getMultiplicityRestrictions(oclass);		
				
				// property -> EReference, Attribute
				for(Iterator itP=oclass.getOwnedProperty().iterator();itP.hasNext();){
					Property p = (Property) itP.next();
					
					EStructuralFeature ep = prop2EStructuralFeature(p);
					
					int lowbound = getLowBound(multiplicity, p);
					int upperbound = getUpperBound(multiplicity, p);

					ep.setLowerBound(lowbound);
					ep.setUpperBound(upperbound);
					
					// set domain
					((EClass)eclass).getEStructuralFeatures().add(ep);
					
					// set range
					EClassifier erange = owl2eclassifier( (p.getRDFSRange().isEmpty() ? 
							null : (RDFSResource)p.getRDFSRange().get(0)) );
					
					if(erange != null) {
						// if property without range, leave it as null
						ep.setEType(erange);
					}
					
					if(p instanceof OWLObjectProperty) {
						Property pinv = ((OWLObjectProperty)p).getOWLInverseOf();
						if(pinv!=null) {
							EReference epinv = (EReference)prop2EStructuralFeature(pinv);
							
							EClass epinvDomain = (EClass)ep.getEType();
							if(epinvDomain!=null){
								// set domain & range of epinv
								epinvDomain.getEStructuralFeatures().add(epinv);
								epinv.setEType(eclass);
								
								epinv.setEOpposite((EReference)ep);
								((EReference)ep).setEOpposite(epinv);
							}
							

						}
					}
					
				}
				
            } 

		}
		
		return epackage;
	}
	

    private EClassifier owl2eclassifier(RDFSResource oclass) {
    	if(oclass==null)
    		return null;
    	
    	EClassifier eclass = (EClassifier)owl2ecoreMap.get(oclass);
    	
    	if(eclass == null) {
    		if(oclass instanceof OWLDataRange || oclass instanceof EnumeratedClass) {
    			// enumerate, datarange -> eenum
    			eclass = oneof2EEnum((RDFSClass)oclass);   			
    		}
    		else if(oclass instanceof RDFSDatatype) {
	            RDFSDatatype dt = (RDFSDatatype) oclass;
	            String dtURI = dt.getURI();
	            if( dtURI != null ) {
	            	if(dtURI.equals(XSD_BOOLEAN) )
	            		eclass = EcorePackage.eINSTANCE.getEBoolean();
	            	else if(dtURI.equals(XSD_FLOAT) )
	            		eclass = EcorePackage.eINSTANCE.getEFloat();
	            	else if(dtURI.equals(XSD_INT))
	            		eclass = EcorePackage.eINSTANCE.getEInt();
	            	else if(dtURI.equals(XSD_BYTE))
	            		eclass = EcorePackage.eINSTANCE.getEByte();
	            	else if(dtURI.equals(XSD_LONG))
	            		eclass = EcorePackage.eINSTANCE.getELong();
	            	else if(dtURI.equals(XSD_DOUBLE))
	            		eclass = EcorePackage.eINSTANCE.getEDouble();
	            	else if(dtURI.equals(XSD_SHORT))
	            		eclass = EcorePackage.eINSTANCE.getEShort();
	            	else if(dtURI.equals(XSD_STRING)|| dtURI.equals(RDFS.C_LITERAL_STR) 
							|| dtURI.equals(RDF.C_XMLLITERAL_STR))
	            		eclass = EcorePackage.eINSTANCE.getEString();
	            	else {
		                // Create a user-defined EDatatType
		                eclass = EcoreFactory.eINSTANCE.createEDataType();
		                eclass.setName( dt.getLocalName() );
		                eclass.getEAnnotations().addAll( createEAnnotation(dt) );
	            	}
	            }
			} 
			else {
				// owlclass
		    	eclass = EcoreFactory.eINSTANCE.createEClass();
		    	
		    	// create name for eclass    	
		    	eclass.setName( oclass.getLocalName());
		    	eclass.getEAnnotations().addAll( createEAnnotation(oclass) );
			}
	    	
			if(eclass!=null)
				owl2ecoreMap.put(oclass,eclass);
    	}
    	
    	return eclass;
    }
	
	private EEnum oneof2EEnum(RDFSClass enumclass) {
		
		EEnum eenum = (EEnum)owl2ecoreMap.get(enumclass);

		if(eenum==null){
			List memberList = null;
			
			if(enumclass instanceof OWLDataRange) {
				memberList = ((OWLDataRange)enumclass).getOWLOneOf();
			} else {
				memberList = ((EnumeratedClass)enumclass).getOWLOneOf();
			}
			
			// if memberList.size > 0, create EEnum
			if (!memberList.isEmpty()) {
				eenum = EcoreFactory.eINSTANCE.createEEnum();
				eenum.setName( enumclass.getLocalName() );
				eenum.getEAnnotations().addAll( createEAnnotation(enumclass) );

				// create enumliterals from enumclass members
				int intValue = 0;
				for (Iterator it = memberList.iterator();it.hasNext();) {
					RDFSResource r = (RDFSResource) (it.next());
					
					// test whether contains label "EEnum"
					String enumeration = (r instanceof RDFSLiteral ? 
							((RDFSLiteral) r).getLexicalForm() : r.getURI());
		
					// create EEnumLiteral
					EEnumLiteral eliteral = EcoreFactory.eINSTANCE.createEEnumLiteral();
					eliteral.getEAnnotations().addAll( createEAnnotation(r) );

					eliteral.setName(enumeration);
					eliteral.setValue(intValue);
					eenum.getELiterals().add(eliteral);
					intValue++;
				}
			}
		}

		return eenum;
	}

	private EStructuralFeature prop2EStructuralFeature(Property p) {
		EStructuralFeature ep = (EStructuralFeature)owl2ecoreMap.get(p);

		if(ep == null) {
			if(p instanceof OWLObjectProperty) {
				ep = EcoreFactory.eINSTANCE.createEReference();
				OWLClass range = p.getRDFSRange().isEmpty() ? null : 
					(OWLClass) ((RDFSResource)p.getRDFSRange().get(0));
				if(range != null) {
					// if property without range, leave it as null
					EClass erange = (EClass)owl2ecoreMap.get(range);
					ep.setEType(erange);
				}
				
				// property attribute to annotation
				Boolean isTransitive = ((OWLObjectProperty)p).getTransitive();
				if( isTransitive!=null && isTransitive.booleanValue() ){
					EAnnotation ea = EcoreFactory.eINSTANCE.createEAnnotation();
					ea.setSource("The property is Transitive.");
					ep.getEAnnotations().add(ea);
				}
				
				Boolean isSymmetric = ((OWLObjectProperty)p).getSymmetric();
				if( isSymmetric!=null && isSymmetric.booleanValue() ) {
					EAnnotation ea = EcoreFactory.eINSTANCE.createEAnnotation();
					ea.setSource("The property is Functional.");
					ep.getEAnnotations().add(ea);
				}
				
				Boolean isInverseFunctional = ((OWLObjectProperty)p).getInverseFunctional() ;
				if( isInverseFunctional!=null && isInverseFunctional.booleanValue() ) {
					EAnnotation ea = EcoreFactory.eINSTANCE.createEAnnotation();
					ea.setSource("The property is Inverse Functional.");
					ep.getEAnnotations().add(ea);
				}

				
			} else {
				// OWLDatatype Property
				ep = EcoreFactory.eINSTANCE.createEAttribute();
			}
			
			String name = getName(p.getLocalName());
			ep.setName( name );
			ep.getEAnnotations().addAll( createEAnnotation(p));
						
			// subPropertyOf will be in eannoations
			for(Iterator itSuper = p.getRDFSSubPropertyOf().iterator();itSuper.hasNext();) {
			    Property superP = (Property) itSuper.next();
			    if (superP != null) {
			        EAnnotation ea = EcoreFactory.eINSTANCE.createEAnnotation();
			        ea.setSource("The property is subPropertyOf " + superP.getLocalName() + ".");
			        ep.getEAnnotations().add(ea);
			    }
			}
			
			//	property attribute to annotation
			Boolean isFunctional = p.getFunctional() ;
			if( isFunctional!= null && isFunctional.booleanValue() ) {
				EAnnotation ea = EcoreFactory.eINSTANCE.createEAnnotation();
				ea.setSource("The property is Functional.");
				ep.getEAnnotations().add(ea);
			}
			
			owl2ecoreMap.put(p,ep);
		}

		return ep;
	}

	
	
    private List createEAnnotation(RDFSResource rs){
    	List lst = new ArrayList(); 
    	
    	// create comments as annotations
    	for(Iterator it = rs.getRDFSComment().iterator();it.hasNext();) {
    		EAnnotation annotation = EcoreFactory.eINSTANCE.createEAnnotation();
    		annotation.setSource("comment - " + ((PlainLiteral) it.next()).getLexicalForm());
    		lst.add(annotation);
    	}

    	// create isDefinedBy as annotations
    	for (Iterator it = rs.getRDFSIsDefinedBy().iterator();it.hasNext();) {
    		EAnnotation annotation = EcoreFactory.eINSTANCE.createEAnnotation();
    		annotation.setSource("isDefinedBy - " + ((RDFSResource) it.next()).getURI());
    		lst.add(annotation);
    	}

    	// create Label as annotations
    	for (Iterator it = rs.getRDFSLabel().iterator();it.hasNext();) {
    		EAnnotation annotation = EcoreFactory.eINSTANCE.createEAnnotation();
    		annotation.setSource("label - " + ((PlainLiteral) it.next()).getLexicalForm());
    		lst.add(annotation);
    	}

    	if(rs instanceof OWLClass) {
    		OWLClass c = (OWLClass)rs;
    		
			// record disjointWith
			for (Iterator it = c.getOWLDisjointWith().iterator();it.hasNext();) {
			    OWLClass owlc = (OWLClass) it.next();
			    if (owlc != null) {
			        EAnnotation annotation = EcoreFactory.eINSTANCE.createEAnnotation();
			        annotation.setSource("The " + c.getURI() + " class is disjoint with " + owlc.getURI() + ".");
			        lst.add(annotation);
			    }
			}
    	}
    	
    	return lst;
    }
    
    private List getMultiplicityRestrictions(OWLClass oclass){
    	List mlst = new ArrayList();
    	
    	for(Iterator itParents = oclass.getRDFSSubClassOf().iterator(); itParents.hasNext();){
    		OWLClass p = (OWLClass) itParents.next(); 
    		if(p instanceof CardinalityRestriction || p instanceof MaxCardinalityRestriction || p instanceof MinCardinalityRestriction){
    			mlst.add(p);
    		}
    	}
    	
    	return mlst;
    }
    
    private int getLowBound(List mlst, Property p){
    	int lowbound = 0;
    	
    	for(Iterator it = mlst.iterator(); it.hasNext();){
    		OWLClass parents = (OWLClass)it.next();;
    		
    		if(parents instanceof CardinalityRestriction) {
    			CardinalityRestriction card = (CardinalityRestriction)parents;
    			if(p == card.getOWLOnProperty() ){
    				RDFSLiteral literal = card.getOWLCardinality();
    				lowbound = Integer.parseInt( literal.getLexicalForm() );
    			}
    		} else if(parents instanceof MinCardinalityRestriction) {
    			MinCardinalityRestriction min = (MinCardinalityRestriction)parents;
    			if(p == min.getOWLOnProperty() ) {
    				RDFSLiteral literal = min.getOWLMinCardinality();
    				lowbound = Integer.parseInt( literal.getLexicalForm() );
    			}
    		}
    	}
    	
    	return lowbound;
    }
    
    private int getUpperBound(List mlst, Property p) {
    	// if property is an object property, default upper bound is -1
    	// if property is an datatype property, default upper bound is 1
    	int upperbound = (p instanceof OWLObjectProperty) ? -1 : 1;
    	
    	for(Iterator it = mlst.iterator(); it.hasNext();){
    		OWLClass parents = (OWLClass)it.next();;
    		
    		if(parents instanceof CardinalityRestriction) {
    			CardinalityRestriction card = (CardinalityRestriction)parents;
    			if(p == card.getOWLOnProperty() ){
    				RDFSLiteral literal = card.getOWLCardinality();
    				upperbound = Integer.parseInt( literal.getLexicalForm() );
    			}
    		} else if(parents instanceof MaxCardinalityRestriction) {
    			MaxCardinalityRestriction max = (MaxCardinalityRestriction)parents;
    			if(p == max.getOWLOnProperty() ) {
    				RDFSLiteral literal = max.getOWLMaxCardinality();
    				upperbound = Integer.parseInt( literal.getLexicalForm() );
    			}
    		}
    	}
    	
    	return upperbound;
    }
    
//	/*
//	 * merge the import ontology to this ontology
//	 */
//	private void mergeOnto() {
//	    
//		List ontologies = ontology.getOWLImports();
//		Iterator oi = ontologies.iterator();
//		while (oi.hasNext()) {
//			OWLOntology owlontology = (OWLOntology) oi.next();
//			//owl2Ecore(owlontology);
//			ontology.getContains().addAll(owlontology.getContains());
//			
//			// log
//			sb.append("Ontology " + owlontology.getLocalName() + " imported successfully!\n");
//		}
//	}
	
    private void saveEcore(EPackage epackage, String outputEcoreFile) throws IOException {
        //save ecore model
		ResourceSet resourceSet = new ResourceSetImpl();
        resourceSet.getResourceFactoryRegistry().getExtensionToFactoryMap()
                .put(Resource.Factory.Registry.DEFAULT_EXTENSION,
                        new EcoreResourceFactoryImpl());

        Resource resource = resourceSet.createResource(URI
                .createFileURI(new File(outputEcoreFile).getAbsolutePath()));
        resource.getContents().add(epackage);

        resource.save(Collections.EMPTY_MAP);
    }
    
	
	
	/**
	 * load OWL file and create a OWL ontology model
	 * 
	 * @return
	 * @throws OWLTransformationException
	 */
	private OWLOntology loadOWLModel(String filePath) throws OWLTransformationException {
		OWLOntology ontology;
		
		try {
			OWLParser parser = new OWLParserImpl();
			
			OWLDocument doc = new OWLDocumentImpl(filePath, null, true);
		    parser.addOWLDocument(doc);
		    ontology = parser.parseOWLDocument(doc);
			
			return ontology;
			
		} catch (Exception e) {
			OWLTransformationException te = new OWLTransformationException(
					"Create OWLModel failed: " + e.getMessage());

			throw te;
		} 

	}
	
	private List getDirectParent(OWLClass oclass) {
		List parents = reasoner.getAncestorClasses(oclass);
		HashSet ancestorSet = new HashSet();
		
		parents.remove(oclass);
		for(Iterator itParents = parents.iterator(); itParents.hasNext();){
			OWLClass p = (OWLClass) itParents.next();
			List ancestors = reasoner.getAncestorClasses(p);
			ancestors.remove(p);
			ancestorSet.addAll(ancestors);
		}
		
		parents.removeAll(ancestorSet);
		return parents;
	}

    
    // load property file and then set parameters
	public void loadProperties(String filename) throws OWLTransformationException  {
		if(filename == null) {
			return;
		}
		
		File file = new File(filename); 
		
		try { 
			FileInputStream in = new FileInputStream(file); 
		    Properties p = new Properties(); 
		    p.load(in); 
		    in.close(); 
		    
		    // read parameters
		    
		    // get property naming methods
		    String vNamingMethods = p.getProperty(KEY_NAMING, DEFAULT_VALUE_NAMING);
		    if( vNamingMethods.equalsIgnoreCase(DEFAULT_VALUE_NAMING) ) {
		    	idNamingMethod = ID_DEFAULT_VALUE_NAMING;
		    } else if ( vNamingMethods.equalsIgnoreCase(NUMBER_SUFFIX) ){
		    	idNamingMethod = ID_NUMBER_SUFFIX;
		    } else {
		    	idNamingMethod = ID_CLASS_PREFIX;
		    }
		    
		    // get delimiters
		    String defaultDelimiter = (idNamingMethod==ID_CLASS_PREFIX) ? 
		    		DELIMITER_CLS : DELIMITER_NUM;
		    naming_delimiter = p.getProperty(KEY_NAMING_DELIMITER, defaultDelimiter);
		    
		} catch (FileNotFoundException e) { 
			throw new OWLTransformationException("Can not find " + filename);
		} catch (IOException e) { 
			throw new OWLTransformationException("Can not read config file " + filename); 
		} 
		
	}
	
	private String getName(String localName){
		String name = null;
		
		switch(idNamingMethod) {
		case ID_NUMBER_SUFFIX:
			int index = localName.lastIndexOf(naming_delimiter);
			name = localName.substring(0, index);
			break;
			
		case ID_CLASS_PREFIX:
			index = localName.indexOf(naming_delimiter);
			name = localName.substring(index+1, localName.length());
			break;
			
		default:
			name = localName;
		}
		
		return name;
	}
	
	
	private void initialize(OWLOntology ontology) {	
		reasoner.initialize(ontology);
		owl2ecoreMap.clear();
	}
	
	OWLTaxonomyReasoner reasoner = StructuralReasonerFactory.instance().createOWLTaxonmyReasoner();
    Map owl2ecoreMap = new HashMap();

	// options
    // property naming option, 
    // possible options: "origin", "number suffix", "class prefix" 
    static final String KEY_NAMING = "PropertyNaming";
    static final String DEFAULT_VALUE_NAMING = "origin";
    static final String NUMBER_SUFFIX = "number suffix";
    static final String CLASS_PREFIX = "class prefix";
    static final int ID_DEFAULT_VALUE_NAMING = 0;
    static final int ID_NUMBER_SUFFIX = 1;
    static final int ID_CLASS_PREFIX = 2;
    int idNamingMethod = ID_DEFAULT_VALUE_NAMING;
	

	// delimiter for naming
    static final String KEY_NAMING_DELIMITER = "NamingDelimiter";
    static final String DELIMITER_NUM = "_";
    static final String DELIMITER_CLS = ".";
    String naming_delimiter = DELIMITER_NUM;
    
    
    private static String OWL_THING = "http://www.w3.org/2002/07/owl#Thing";

    private static String XSD_BOOLEAN = "http://www.w3.org/2001/XMLSchema#boolean";
    private static String XSD_FLOAT = "http://www.w3.org/2001/XMLSchema#float";
    private static String XSD_BYTE = "http://www.w3.org/2001/XMLSchema#byte";
    private static String XSD_INT = "http://www.w3.org/2001/XMLSchema#int";
    private static String XSD_LONG = "http://www.w3.org/2001/XMLSchema#long";
    private static String XSD_DOUBLE = "http://www.w3.org/2001/XMLSchema#double";
    private static String XSD_SHORT = "http://www.w3.org/2001/XMLSchema#short";
    //private static String XSD_INTEGER = "http://www.w3.org/2001/XMLSchema#integer";
    private static String XSD_STRING = "http://www.w3.org/2001/XMLSchema#string";


    

}
