/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved.   This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 * 
 * $Id: RDFXMLSaverHelper.java,v 1.1.1.1 2006/01/31 09:13:26 gxie Exp $
 */

package org.eclipse.eodm.rdf.resource;

import org.eclipse.eodm.rdfs.RDFSLiteral;
import org.eclipse.eodm.rdfs.RDFSPackage;
import org.eclipse.eodm.rdfs.RDFSResource;
import org.eclipse.eodm.rdfs.vocabulary.RDFS;

/**
 * Helper class for RDFXMLSaver.
 *  
 */
class RDFXMLSaverHelper {

    /**
     * Judges whether a RDFSResource is a RDF blank node.
     * 
     * @param res
     *            the resource to be judged
     * @return whether the resource is a RDF blank node.
     */
    public static boolean isBlankNode(RDFSResource res) {
        if (res instanceof RDFSLiteral)
            return false;
        if (res.getNamespace() != null)
            if (res.getNamespace().getURI().equals(RDFS.BNODE_NAMESPACE))
                return true;
        return false;
    }

    /**
     * Judges whether a RDFSResource is a RDF literal.
     * 
     * @param res
     *            the resource to be judged
     * @return whether the resource is a RDF literal
     */
    public static boolean isLiteral(RDFSResource res) {
        switch (res.eClass().getClassifierID()) {
        case RDFSPackage.RDFS_LITERAL:
        case RDFSPackage.PLAIN_LITERAL:
        case RDFSPackage.TYPED_LITERAL:
        case RDFSPackage.RDFXML_LITERAL:
            return true;
        default:
            return false;
        }
    }
}