/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 * 
 * $Id: RDFTypeConstants.java,v 1.1.1.1 2006/01/31 09:13:26 gxie Exp $
 */

package org.eclipse.eodm.rdf.resource.parser.wrapper;

import org.eclipse.eodm.rdfs.vocabulary.RDF;
import org.eclipse.eodm.rdfs.vocabulary.RDFS;

/**
 * RDFTypeConstants
 * 
 * All the anonymous nodes are typed as RDFS_RESOURCE.
 * 
 * 1. Elements defined in RDF vovabulary. (1)Syntax names �� not concepts RDF
 * Description ID about parseType resource li nodeID datatype (2)Class names Seq
 * Bag Alt Statement Property XMLLiteral List (3)Property names subject,
 * predicate, object, type, value, first, rest (_n where n is an integer greater
 * than zero without leading zeros) (4)Resource names nil All class names
 * defined in RDF should be identified as one type.
 * 
 * 2. Elements defined in RDFS vocabulary. (1)Class names Resource Class Literal
 * Datatype Container ContainerMembershipProperty (2)Property names domain range
 * subClassOf subPropertyOf label comment member seeAlso isDefinedBy All class
 * names defined in RDFS should also be identified as one type.
 *  
 */
public final class RDFTypeConstants {
    private RDFTypeConstants() {
    }

    /** 1 - rdf alt type */
    public static final int RDF_ALT = 1;

    /** 2 - rdf seq type */
    public static final int RDF_SEQ = 2;

    /** 3 - rdf bag type */
    public static final int RDF_BAG = 3;

    /** 4 - rdf statement type */
    public static final int RDF_STATEMENT = 4;

    /** 5 - rdf property type */
    public static final int RDF_PROPERTY = 5;

    /** 6 - rdf xml literal type */
    public static final int RDF_XMLLITERAL = 6;

    /** 7 - rdf list type */
    public static final int RDF_LIST = 7;

    /** 8 - other */
    public static final int UNKNOWN_TYPE = 8;

    /** 9 - resource type */
    public static final int RDFS_RESOURCE = 9;

    /** 10 - rdfs class type */
    public static final int RDFS_CLASS = 10;

    /** 11 - rdfs literal type */
    public static final int RDFS_LITERAL = 11;

    /** 12 - rdfs datatype type */
    public static final int RDFS_DATATYPE = 12;

    /** 13 - rdfs container type */
    public static final int RDFS_CONTAINER = 13;

    /** 14 - rdfs container membership property type */
    public static final int RDFS_CONTAINER_MEMEBERSHIP_PROPERTY = 14;

    /**
     * Get the element type according to the object's full uri. Identify objects
     * of those triples with "rdf:type" predicate.
     * 
     * @param uri
     *            the object uri
     * @return the int type
     */
    public static int getRDFElementType(String uri) {
        if (null == uri || "".equals(uri))
            return UNKNOWN_TYPE;

        if (uri.equals(RDF.C_ALT_STR))
            return RDF_ALT;
        if (uri.equals(RDF.C_BAG_STR))
            return RDF_BAG;
        if (uri.equals(RDF.C_SEQ_STR))
            return RDF_SEQ;
        if (uri.equals(RDF.C_STATEMENT_STR))
            return RDF_STATEMENT;
        if (uri.equals(RDF.C_PROPERTY_STR))
            return RDF_PROPERTY;
        if (uri.equals(RDF.C_XMLLITERAL_STR))
            return RDF_XMLLITERAL;
        if (uri.equals(RDF.C_LIST_STR))
            return RDF_LIST;

        if (uri.equals(RDFS.C_RESOURCE_STR))
            return RDFS_RESOURCE;
        if (uri.equals(RDFS.C_CLASS_STR))
            return RDFS_CLASS;
        if (uri.equals(RDFS.C_LITERAL_STR))
            return RDFS_LITERAL;
        if (uri.equals(RDFS.C_DATATYPE_STR))
            return RDFS_DATATYPE;
        if (uri.equals(RDFS.CONTAINER_STR))
            return RDFS_CONTAINER;
        if (uri.equals(RDFS.CONTAINERMEMBERSHIPPROPERTY_STR))
            return RDFS_CONTAINER_MEMEBERSHIP_PROPERTY;

        return UNKNOWN_TYPE;
    }
}