/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 * 
 * $Id: RDFTypeGenerator.java,v 1.1.1.1 2006/01/31 09:13:26 gxie Exp $
 */

package org.eclipse.eodm.rdf.resource.parser.wrapper;

import org.eclipse.eodm.rdfs.Namespace;
import org.eclipse.eodm.rdfs.RDFAlt;
import org.eclipse.eodm.rdfs.RDFBag;
import org.eclipse.eodm.rdfs.RDFList;
import org.eclipse.eodm.rdfs.RDFProperty;
import org.eclipse.eodm.rdfs.RDFSClass;
import org.eclipse.eodm.rdfs.RDFSContainer;
import org.eclipse.eodm.rdfs.RDFSDatatype;
import org.eclipse.eodm.rdfs.RDFSFactory;
import org.eclipse.eodm.rdfs.RDFSResource;
import org.eclipse.eodm.rdfs.RDFSeq;
import org.eclipse.eodm.rdfs.RDFStatement;

/**
 * RDFTypeGenerator All the methods to create RDF Type Elements.
 */
public final class RDFTypeGenerator {
    private RDFTypeGenerator() {
    }

    /** The single instance of RDFTypeGenerator */
    public static final RDFTypeGenerator _INSTANCE = new RDFTypeGenerator();

    /** Create an rdf Alt container */
    public RDFAlt createAlt(Namespace namespace, String localName) {
        RDFAlt alt = RDFSFactory.eINSTANCE.createRDFAlt();
        alt.setNamespace(namespace);
        alt.setLocalName(localName);
        return alt;
    }

    /** Create an rdf Bag container */
    public RDFBag createBag(Namespace namespace, String localName) {
        RDFBag bag = RDFSFactory.eINSTANCE.createRDFBag();
        bag.setNamespace(namespace);
        bag.setLocalName(localName);
        return bag;
    }

    /** Create an rdf Seq container */
    public RDFSeq createSeq(Namespace namespace, String localName) {
        RDFSeq seq = RDFSFactory.eINSTANCE.createRDFSeq();
        seq.setNamespace(namespace);
        seq.setLocalName(localName);
        return seq;
    }

    /** Create an rdfs Container */
    public RDFSContainer createContainer(Namespace namespace, String localName) {
        RDFSContainer container = RDFSFactory.eINSTANCE.createRDFSContainer();
        container.setNamespace(namespace);
        container.setLocalName(localName);
        return container;
    }

    /** Create an rdf Property */
    public RDFProperty createProperty(Namespace namespace, String localName) {
        RDFProperty property = RDFSFactory.eINSTANCE.createRDFProperty();
        property.setNamespace(namespace);
        property.setLocalName(localName);
        return property;
    }

    /** Create an rdf Statement */
    public RDFStatement createStatement(Namespace namespace, String localName) {
        RDFStatement statement = RDFSFactory.eINSTANCE.createRDFStatement();
        statement.setNamespace(namespace);
        statement.setLocalName(localName);
        return statement;
    }

    /** Create an rdf List */
    public RDFList createList(Namespace namespace, String localName) {
        RDFList list = RDFSFactory.eINSTANCE.createRDFList();
        list.setNamespace(namespace);
        list.setLocalName(localName);
        return list;
    }

    /** Create an rdfs Resource */
    public RDFSResource createResource(Namespace namespace, String localName) {
        RDFSResource resource = RDFSFactory.eINSTANCE.createRDFSResource();
        resource.setNamespace(namespace);
        resource.setLocalName(localName);
        return resource;
    }

    /** Create an rdfs Class */
    public RDFSClass createClass(Namespace namespace, String localName) {
        RDFSClass cls = RDFSFactory.eINSTANCE.createRDFSClass();
        cls.setNamespace(namespace);
        cls.setLocalName(localName);
        return cls;
    }

    /** Create an rdfs Datatype */
    public RDFSDatatype createDatatype(Namespace namespace, String localName) {
        RDFSDatatype datatype = RDFSFactory.eINSTANCE.createRDFSDatatype();
        datatype.setNamespace(namespace);
        datatype.setLocalName(localName);
        return datatype;
    }
}