/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved.   This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 *
 * $Id: Ontology.java,v 1.1.1.1 2006/01/31 09:13:24 gxie Exp $
 */
package org.eclipse.eodm.rdfs;

import java.util.List;

import org.eclipse.emf.common.util.EList;
import org.eclipse.eodm.rdfs.reasoner.RDFSReasoner;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>RDF Description</b></em>'. <!-- end-user-doc -->
 * 
 * <p>
 * The following features are supported:
 * <ul>
 * <li>{@link org.eclipse.eodm.rdfs.Ontology#getContains <em>Contains</em>}</li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.Ontology#getOwnedNamespace <em>Owned Namespace</em>}
 * </li>
 * </ul>
 * </p>
 * 
 * @see org.eclipse.eodm.rdfs.RDFSPackage#getOntology()
 * @model
 * @generated
 */
public interface Ontology extends RDFSResource {
    /**
     * Returns the value of the '<em><b>Contains</b></em>' containment
     * reference list. The list contents are of type
     * {@link org.eclipse.eodm.rdfs.RDFSResource}. <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @return the value of the '<em>Contains</em>' containment reference
     *         list.
     * @see org.eclipse.eodm.rdfs.RDFSPackage#getOntology_Contains()
     * @model type="org.eclipse.rdfs.RDFSResource" containment="true"
     * @generated
     */
    EList getContains();

    /**
     * Returns the value of the '<em><b>Owned Namespace</b></em>'
     * containment reference list. The list contents are of type
     * {@link org.eclipse.eodm.rdfs.Namespace}. <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @return the value of the '<em>Owned Namespace</em>' containment
     *         reference list.
     * @see org.eclipse.eodm.rdfs.RDFSPackage#getOntology_OwnedNamespace()
     * @model type="org.eclipse.rdfs.Namespace" containment="true"
     * @generated
     */
    EList getOwnedNamespace();

    /**
     * Get resources with specific type from the container - RDFDescription
     * 
     * @param resourceType
     *            resource type that want to get, such as RDFSClass or
     *            RDFProperty
     * @return null if not exist
     */
    List getResourceList(Class resourceType);

    /**
     * Get contained resource by localName or URI (namespace + localName)
     * 
     * @param namespace,
     *            namespace class of the specific resource
     * @param name,
     *            localName of the specific resource
     * @return
     */
    RDFSResource getContainedResource(Namespace namespace, String localName);

    /**
     * Get associated reasoner
     * 
     * @return reasoner
     */
    public RDFSReasoner getReasoner();

    /**
     * Set associated reasoner
     * 
     * @param reasoner
     */
    public void bindReasoner(RDFSReasoner reasoner);

} // RDFDescription
