/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved.   This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 *
 * $Id: RDFProperty.java,v 1.1.1.1 2006/01/31 09:13:25 gxie Exp $
 */
package org.eclipse.eodm.rdfs;

import org.eclipse.emf.common.util.EList;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>RDF Property</b></em>'. <!-- end-user-doc -->
 * 
 * <p>
 * The following features are supported:
 * <ul>
 * <li>
 * {@link org.eclipse.eodm.rdfs.RDFProperty#getRefByRestriction <em>Ref By Restriction</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.RDFProperty#getRDFSSubPropertyOf <em>RDFS Sub Property Of</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.RDFProperty#getSubProperty <em>Sub Property</em>}
 * </li>
 * <li>{@link org.eclipse.eodm.rdfs.RDFProperty#getRDFSDomain <em>RDFS Domain</em>}
 * </li>
 * <li>{@link org.eclipse.eodm.rdfs.RDFProperty#getRDFSRange <em>RDFS Range</em>}
 * </li>
 * </ul>
 * </p>
 * 
 * @see org.eclipse.eodm.rdfs.RDFSPackage#getRDFProperty()
 * @model
 * @generated
 */
public interface RDFProperty extends RDFSResource {
    /**
     * Returns the value of the '<em><b>Ref By Restriction</b></em>'
     * reference list. The list contents are of type
     * {@link org.eclipse.eodm.owl.OWLRestriction}. It is bidirectional and its
     * opposite is '
     * {@link org.eclipse.eodm.owl.OWLRestriction#getOWLOnProperty <em>OWL On Property</em>}'.
     * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @return the value of the '<em>Ref By Restriction</em>' reference
     *         list.
     * @see org.eclipse.eodm.rdfs.RDFSPackage#getRDFProperty_RefByRestriction()
     * @see org.eclipse.eodm.owl.OWLRestriction#getOWLOnProperty
     * @model type="org.eclipse.owl.OWLRestriction" opposite="OWLOnProperty"
     * @generated
     */
    EList getRefByRestriction();

    /**
     * Returns the value of the '<em><b>RDFS Sub Property Of</b></em>'
     * reference list. The list contents are of type
     * {@link org.eclipse.eodm.rdfs.RDFProperty}. It is bidirectional and its
     * opposite is '
     * {@link org.eclipse.eodm.rdfs.RDFProperty#getSubProperty <em>Sub Property</em>}'.
     * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @return the value of the '<em>RDFS Sub Property Of</em>' reference
     *         list.
     * @see org.eclipse.eodm.rdfs.RDFSPackage#getRDFProperty_RDFSSubPropertyOf()
     * @see org.eclipse.eodm.rdfs.RDFProperty#getSubProperty
     * @model type="org.eclipse.rdfs.RDFProperty" opposite="subProperty"
     * @generated
     */
    EList getRDFSSubPropertyOf();

    /**
     * Returns the value of the '<em><b>RDFS Sub Property Of</b></em>'
     * reference list. The list contents are of type
     * {@link org.eclipse.eodm.rdfs.RDFProperty}. It is bidirectional and its
     * opposite is '
     * {@link org.eclipse.eodm.rdfs.RDFProperty#getSubProperty <em>Sub Property</em>}'.
     * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @param if
     *            bInference is true, it will give an answer after inference
     * @return the value of the '<em>RDFS Sub Property Of</em>' reference
     *         list.
     * @see org.eclipse.eodm.rdfs.RDFSPackage#getRDFProperty_RDFSSubPropertyOf()
     * @see org.eclipse.eodm.rdfs.RDFProperty#getSubProperty
     * @model type="org.eclipse.rdfs.RDFProperty" opposite="subProperty"
     */
    EList getRDFSSubPropertyOf(boolean bInference);

    /**
     * Returns the value of the '<em><b>Sub Property</b></em>' reference
     * list. The list contents are of type {@link org.eclipse.eodm.rdfs.RDFProperty}.
     * It is bidirectional and its opposite is '
     * {@link org.eclipse.eodm.rdfs.RDFProperty#getRDFSSubPropertyOf <em>RDFS Sub Property Of</em>}'.
     * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @return the value of the '<em>Sub Property</em>' reference list.
     * @see org.eclipse.eodm.rdfs.RDFSPackage#getRDFProperty_SubProperty()
     * @see org.eclipse.eodm.rdfs.RDFProperty#getRDFSSubPropertyOf
     * @model type="org.eclipse.rdfs.RDFProperty" opposite="RDFSSubPropertyOf"
     * @generated
     */
    EList getSubProperty();

    /**
     * Returns the value of the '<em><b>Sub Property</b></em>' reference
     * list. The list contents are of type {@link org.eclipse.eodm.rdfs.RDFProperty}.
     * It is bidirectional and its opposite is '
     * {@link org.eclipse.eodm.rdfs.RDFProperty#getRDFSSubPropertyOf <em>RDFS Sub Property Of</em>}'.
     * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @param if
     *            bInference is true, it will give an answer after inference
     * @return the value of the '<em>Sub Property</em>' reference list.
     * @see org.eclipse.eodm.rdfs.RDFSPackage#getRDFProperty_SubProperty()
     * @see org.eclipse.eodm.rdfs.RDFProperty#getRDFSSubPropertyOf
     * @model type="org.eclipse.rdfs.RDFProperty" opposite="RDFSSubPropertyOf"
     */
    EList getSubProperty(boolean bInference);

    /**
     * Returns the value of the '<em><b>RDFS Domain</b></em>' reference
     * list. The list contents are of type {@link org.eclipse.eodm.rdfs.RDFSClass}.
     * It is bidirectional and its opposite is '
     * {@link org.eclipse.eodm.rdfs.RDFSClass#getOwnedProperty <em>Owned Property</em>}'.
     * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @return the value of the '<em>RDFS Domain</em>' reference list.
     * @see org.eclipse.eodm.rdfs.RDFSPackage#getRDFProperty_RDFSDomain()
     * @see org.eclipse.eodm.rdfs.RDFSClass#getOwnedProperty
     * @model type="org.eclipse.rdfs.RDFSClass" opposite="ownedProperty"
     * @generated
     */
    EList getRDFSDomain();

    /**
     * Returns the value of the '<em><b>RDFS Range</b></em>' reference
     * list. The list contents are of type {@link org.eclipse.eodm.rdfs.RDFSClass}.
     * It is bidirectional and its opposite is '
     * {@link org.eclipse.eodm.rdfs.RDFSClass#getRangedByProperty <em>Ranged By Property</em>}'.
     * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @return the value of the '<em>RDFS Range</em>' reference list.
     * @see org.eclipse.eodm.rdfs.RDFSPackage#getRDFProperty_RDFSRange()
     * @see org.eclipse.eodm.rdfs.RDFSClass#getRangedByProperty
     * @model type="org.eclipse.rdfs.RDFSClass" opposite="rangedByProperty"
     * @generated
     */
    EList getRDFSRange();

} // RDFProperty
