/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved.   This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 *
 * $Id: RDFSResourceImpl.java,v 1.2 2006/06/22 05:07:46 gxie Exp $
 */
package org.eclipse.eodm.rdfs.impl;

import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Vector;

import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.NotificationChain;
import org.eclipse.emf.common.util.BasicEList;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.emf.ecore.InternalEObject;
import org.eclipse.emf.ecore.impl.ENotificationImpl;
import org.eclipse.emf.ecore.impl.EObjectImpl;
import org.eclipse.emf.ecore.util.EObjectResolvingEList;
import org.eclipse.emf.ecore.util.EObjectWithInverseResolvingEList;
import org.eclipse.emf.ecore.util.InternalEList;
import org.eclipse.eodm.rdfs.Namespace;
import org.eclipse.eodm.rdfs.Ontology;
import org.eclipse.eodm.rdfs.PlainLiteral;
import org.eclipse.eodm.rdfs.RDFProperty;
import org.eclipse.eodm.rdfs.RDFSClass;
import org.eclipse.eodm.rdfs.RDFSFactory;
import org.eclipse.eodm.rdfs.RDFSPackage;
import org.eclipse.eodm.rdfs.RDFSResource;
import org.eclipse.eodm.rdfs.RDFStatement;

/**
 * <!-- begin-user-doc --> An implementation of the model object '
 * <em><b>RDFS Resource</b></em>'. <!-- end-user-doc -->
 * <p>
 * The following features are implemented:
 * <ul>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getLocalName <em>Local Name</em>}
 * </li>
 * <li>{@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getURI <em>URI</em>}</li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getSubjectStatement <em>Subject Statement</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getObjectStatement <em>Object Statement</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getRDFSIsDefinedBy <em>RDFS Is Defined By</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getRDFValue <em>RDF Value</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getRDFSSeeAlso <em>RDFS See Also</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getRDFType <em>RDF Type</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getRDFSMember <em>RDFS Member</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getPredicateStatement <em>Predicate Statement</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getRDFSComment <em>RDFS Comment</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getRDFSLabel <em>RDFS Label</em>}
 * </li>
 * <li>
 * {@link org.eclipse.eodm.rdfs.impl.RDFSResourceImpl#getNamespace <em>Namespace</em>}
 * </li>
 * </ul>
 * </p>
 * 
 * @generated
 */
public class RDFSResourceImpl extends EObjectImpl implements RDFSResource {
    /**
     * The default value of the '{@link #getLocalName() <em>Local Name</em>}'
     * attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getLocalName()
     * @generated
     * @ordered
     */
    protected static final String LOCAL_NAME_EDEFAULT = null;

    /**
     * The cached value of the '{@link #getLocalName() <em>Local Name</em>}'
     * attribute. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getLocalName()
     * @generated
     * @ordered
     */
    protected String localName = LOCAL_NAME_EDEFAULT;

    /**
     * The default value of the '{@link #getURI() <em>URI</em>}' attribute.
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getURI()
     * @generated
     * @ordered
     */
    protected static final String URI_EDEFAULT = null;

    /**
     * The cached value of the '
     * {@link #getSubjectStatement() <em>Subject Statement</em>}' reference
     * list. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getSubjectStatement()
     * @generated
     * @ordered
     */
    protected EList subjectStatement = null;

    /**
     * The cached value of the '
     * {@link #getObjectStatement() <em>Object Statement</em>}' reference list.
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getObjectStatement()
     * @generated
     * @ordered
     */
    protected EList objectStatement = null;

    /**
     * The cached value of the '
     * {@link #getRDFSIsDefinedBy() <em>RDFS Is Defined By</em>}' reference
     * list. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getRDFSIsDefinedBy()
     * @generated
     * @ordered
     */
    protected EList rdfsIsDefinedBy = null;

    /**
     * The cached value of the '{@link #getRDFValue() <em>RDF Value</em>}'
     * reference list. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getRDFValue()
     * @generated
     * @ordered
     */
    protected EList rdfValue = null;

    /**
     * The cached value of the '
     * {@link #getRDFSSeeAlso() <em>RDFS See Also</em>}' reference list. <!--
     * begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getRDFSSeeAlso()
     * @generated
     * @ordered
     */
    protected EList rdfsSeeAlso = null;

    /**
     * The cached value of the '{@link #getRDFType() <em>RDF Type</em>}'
     * reference list. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getRDFType()
     * @generated
     * @ordered
     */
    protected EList rdfType = null;

    /**
     * The cached value of the '{@link #getRDFSMember() <em>RDFS Member</em>}'
     * reference list. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getRDFSMember()
     * @generated
     * @ordered
     */
    protected EList rdfsMember = null;

    /**
     * The cached value of the '
     * {@link #getPredicateStatement() <em>Predicate Statement</em>}' reference
     * list. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getPredicateStatement()
     * @generated
     * @ordered
     */
    protected EList predicateStatement = null;

    /**
     * The cached value of the '{@link #getRDFSComment() <em>RDFS Comment</em>}'
     * reference list. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getRDFSComment()
     * @generated
     * @ordered
     */
    protected EList rdfsComment = null;

    /**
     * The cached value of the '{@link #getRDFSLabel() <em>RDFS Label</em>}'
     * reference list. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getRDFSLabel()
     * @generated
     * @ordered
     */
    protected EList rdfsLabel = null;

    /**
     * The cached value of the '{@link #getNamespace() <em>Namespace</em>}'
     * reference. <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @see #getNamespace()
     * @generated
     * @ordered
     */
    protected Namespace namespace = null;

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    protected RDFSResourceImpl() {
        super();
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    protected EClass eStaticClass() {
        return RDFSPackage.eINSTANCE.getRDFSResource();
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public String getLocalName() {
        return localName;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public void setLocalName(String newLocalName) {
        String oldLocalName = localName;
        localName = newLocalName;
        if (eNotificationRequired())
            eNotify(new ENotificationImpl(this, Notification.SET,
                    RDFSPackage.RDFS_RESOURCE__LOCAL_NAME, oldLocalName,
                    localName));
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated NOT
     */
    public String getURI() {
        if (namespace == null){
            if (this.eContainer() != null){
                namespace = ((Ontology)this.eContainer()).getNamespace();
            }
        }
        
        if (namespace == null || localName == null)
            return "";
        return (namespace.getURI() + localName);
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public EList getSubjectStatement() {
        if (subjectStatement == null) {
            subjectStatement = new EObjectWithInverseResolvingEList(
                    RDFStatement.class, this,
                    RDFSPackage.RDFS_RESOURCE__SUBJECT_STATEMENT,
                    RDFSPackage.RDFS_TATEMENT__RDF_SUBJECT);
        }
        return subjectStatement;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public EList getObjectStatement() {
        if (objectStatement == null) {
            objectStatement = new EObjectWithInverseResolvingEList(
                    RDFStatement.class, this,
                    RDFSPackage.RDFS_RESOURCE__OBJECT_STATEMENT,
                    RDFSPackage.RDFS_TATEMENT__RDF_OBJECT);
        }
        return objectStatement;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public EList getRDFSIsDefinedBy() {
        if (rdfsIsDefinedBy == null) {
            rdfsIsDefinedBy = new EObjectResolvingEList(RDFSResource.class,
                    this, RDFSPackage.RDFS_RESOURCE__RDFS_IS_DEFINED_BY);
        }
        return rdfsIsDefinedBy;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public EList getRDFValue() {
        if (rdfValue == null) {
            rdfValue = new EObjectResolvingEList(RDFSResource.class, this,
                    RDFSPackage.RDFS_RESOURCE__RDF_VALUE);
        }
        return rdfValue;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public EList getRDFSSeeAlso() {
        if (rdfsSeeAlso == null) {
            rdfsSeeAlso = new EObjectResolvingEList(RDFSResource.class, this,
                    RDFSPackage.RDFS_RESOURCE__RDFS_SEE_ALSO);
        }
        return rdfsSeeAlso;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public EList getRDFType() {
        if (rdfType == null) {
            rdfType = new EObjectWithInverseResolvingEList.ManyInverse(
                    RDFSClass.class, this, RDFSPackage.RDFS_RESOURCE__RDF_TYPE,
                    RDFSPackage.RDFS_CLASS__INSTANCE);
        }
        return rdfType;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public EList getRDFSMember() {
        if (rdfsMember == null) {
            rdfsMember = new EObjectResolvingEList(RDFSResource.class, this,
                    RDFSPackage.RDFS_RESOURCE__RDFS_MEMBER);
        }
        return rdfsMember;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public EList getPredicateStatement() {
        if (predicateStatement == null) {
            predicateStatement = new EObjectWithInverseResolvingEList(
                    RDFStatement.class, this,
                    RDFSPackage.RDFS_RESOURCE__PREDICATE_STATEMENT,
                    RDFSPackage.RDFS_TATEMENT__RDF_PREDICATE);
        }
        return predicateStatement;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public EList getRDFSComment() {
        if (rdfsComment == null) {
            rdfsComment = new EObjectResolvingEList(PlainLiteral.class, this,
                    RDFSPackage.RDFS_RESOURCE__RDFS_COMMENT);
        }
        return rdfsComment;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public EList getRDFSLabel() {
        if (rdfsLabel == null) {
            rdfsLabel = new EObjectResolvingEList(PlainLiteral.class, this,
                    RDFSPackage.RDFS_RESOURCE__RDFS_LABEL);
        }
        return rdfsLabel;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public Namespace getNamespace() {
        
        // get namespace of ontology as the default namespace of a resource        
        if (namespace == null){
        	EObject eo = this;
            while (eo.eContainer() != null){
            	if (eo.eContainer() instanceof Ontology){
                    namespace = ((Ontology)eo.eContainer()).getNamespace();
                    return namespace;
            	}else{
            		eo = eo.eContainer();
            	}
            }
        }
        if (namespace != null && namespace.eIsProxy()) {
            Namespace oldNamespace = namespace;
            namespace = (Namespace) eResolveProxy((InternalEObject) namespace);
            if (namespace != oldNamespace) {
                if (eNotificationRequired())
                    eNotify(new ENotificationImpl(this, Notification.RESOLVE,
                            RDFSPackage.RDFS_RESOURCE__NAMESPACE, oldNamespace,
                            namespace));
            }
        }
        return namespace;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public Namespace basicGetNamespace() {
        return namespace;
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public void setNamespace(Namespace newNamespace) {
        Namespace oldNamespace = namespace;
        namespace = newNamespace;
        if (eNotificationRequired())
            eNotify(new ENotificationImpl(this, Notification.SET,
                    RDFSPackage.RDFS_RESOURCE__NAMESPACE, oldNamespace,
                    namespace));
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public NotificationChain eInverseAdd(InternalEObject otherEnd,
            int featureID, Class baseClass, NotificationChain msgs) {
        if (featureID >= 0) {
            switch (eDerivedStructuralFeatureID(featureID, baseClass)) {
            case RDFSPackage.RDFS_RESOURCE__SUBJECT_STATEMENT:
                return ((InternalEList) getSubjectStatement()).basicAdd(
                        otherEnd, msgs);
            case RDFSPackage.RDFS_RESOURCE__OBJECT_STATEMENT:
                return ((InternalEList) getObjectStatement()).basicAdd(
                        otherEnd, msgs);
            case RDFSPackage.RDFS_RESOURCE__RDF_TYPE:
                return ((InternalEList) getRDFType()).basicAdd(otherEnd, msgs);
            case RDFSPackage.RDFS_RESOURCE__PREDICATE_STATEMENT:
                return ((InternalEList) getPredicateStatement()).basicAdd(
                        otherEnd, msgs);
            default:
                return eDynamicInverseAdd(otherEnd, featureID, baseClass, msgs);
            }
        }
        if (eContainer != null)
            msgs = eBasicRemoveFromContainer(msgs);
        return eBasicSetContainer(otherEnd, featureID, msgs);
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public NotificationChain eInverseRemove(InternalEObject otherEnd,
            int featureID, Class baseClass, NotificationChain msgs) {
        if (featureID >= 0) {
            switch (eDerivedStructuralFeatureID(featureID, baseClass)) {
            case RDFSPackage.RDFS_RESOURCE__SUBJECT_STATEMENT:
                return ((InternalEList) getSubjectStatement()).basicRemove(
                        otherEnd, msgs);
            case RDFSPackage.RDFS_RESOURCE__OBJECT_STATEMENT:
                return ((InternalEList) getObjectStatement()).basicRemove(
                        otherEnd, msgs);
            case RDFSPackage.RDFS_RESOURCE__RDF_TYPE:
                return ((InternalEList) getRDFType()).basicRemove(otherEnd,
                        msgs);
            case RDFSPackage.RDFS_RESOURCE__PREDICATE_STATEMENT:
                return ((InternalEList) getPredicateStatement()).basicRemove(
                        otherEnd, msgs);
            default:
                return eDynamicInverseRemove(otherEnd, featureID, baseClass,
                        msgs);
            }
        }
        return eBasicSetContainer(null, featureID, msgs);
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public Object eGet(EStructuralFeature eFeature, boolean resolve) {
        switch (eDerivedStructuralFeatureID(eFeature)) {
        case RDFSPackage.RDFS_RESOURCE__LOCAL_NAME:
            return getLocalName();
        case RDFSPackage.RDFS_RESOURCE__URI:
            return getURI();
        case RDFSPackage.RDFS_RESOURCE__SUBJECT_STATEMENT:
            return getSubjectStatement();
        case RDFSPackage.RDFS_RESOURCE__OBJECT_STATEMENT:
            return getObjectStatement();
        case RDFSPackage.RDFS_RESOURCE__RDFS_IS_DEFINED_BY:
            return getRDFSIsDefinedBy();
        case RDFSPackage.RDFS_RESOURCE__RDF_VALUE:
            return getRDFValue();
        case RDFSPackage.RDFS_RESOURCE__RDFS_SEE_ALSO:
            return getRDFSSeeAlso();
        case RDFSPackage.RDFS_RESOURCE__RDF_TYPE:
            return getRDFType();
        case RDFSPackage.RDFS_RESOURCE__RDFS_MEMBER:
            return getRDFSMember();
        case RDFSPackage.RDFS_RESOURCE__PREDICATE_STATEMENT:
            return getPredicateStatement();
        case RDFSPackage.RDFS_RESOURCE__RDFS_COMMENT:
            return getRDFSComment();
        case RDFSPackage.RDFS_RESOURCE__RDFS_LABEL:
            return getRDFSLabel();
        case RDFSPackage.RDFS_RESOURCE__NAMESPACE:
            if (resolve)
                return getNamespace();
            return basicGetNamespace();
        }
        return eDynamicGet(eFeature, resolve);
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public void eSet(EStructuralFeature eFeature, Object newValue) {
        switch (eDerivedStructuralFeatureID(eFeature)) {
        case RDFSPackage.RDFS_RESOURCE__LOCAL_NAME:
            setLocalName((String) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__SUBJECT_STATEMENT:
            getSubjectStatement().clear();
            getSubjectStatement().addAll((Collection) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__OBJECT_STATEMENT:
            getObjectStatement().clear();
            getObjectStatement().addAll((Collection) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__RDFS_IS_DEFINED_BY:
            getRDFSIsDefinedBy().clear();
            getRDFSIsDefinedBy().addAll((Collection) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__RDF_VALUE:
            getRDFValue().clear();
            getRDFValue().addAll((Collection) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__RDFS_SEE_ALSO:
            getRDFSSeeAlso().clear();
            getRDFSSeeAlso().addAll((Collection) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__RDF_TYPE:
            getRDFType().clear();
            getRDFType().addAll((Collection) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__RDFS_MEMBER:
            getRDFSMember().clear();
            getRDFSMember().addAll((Collection) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__PREDICATE_STATEMENT:
            getPredicateStatement().clear();
            getPredicateStatement().addAll((Collection) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__RDFS_COMMENT:
            getRDFSComment().clear();
            getRDFSComment().addAll((Collection) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__RDFS_LABEL:
            getRDFSLabel().clear();
            getRDFSLabel().addAll((Collection) newValue);
            return;
        case RDFSPackage.RDFS_RESOURCE__NAMESPACE:
            setNamespace((Namespace) newValue);
            return;
        }
        eDynamicSet(eFeature, newValue);
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public void eUnset(EStructuralFeature eFeature) {
        switch (eDerivedStructuralFeatureID(eFeature)) {
        case RDFSPackage.RDFS_RESOURCE__LOCAL_NAME:
            setLocalName(LOCAL_NAME_EDEFAULT);
            return;
        case RDFSPackage.RDFS_RESOURCE__SUBJECT_STATEMENT:
            getSubjectStatement().clear();
            return;
        case RDFSPackage.RDFS_RESOURCE__OBJECT_STATEMENT:
            getObjectStatement().clear();
            return;
        case RDFSPackage.RDFS_RESOURCE__RDFS_IS_DEFINED_BY:
            getRDFSIsDefinedBy().clear();
            return;
        case RDFSPackage.RDFS_RESOURCE__RDF_VALUE:
            getRDFValue().clear();
            return;
        case RDFSPackage.RDFS_RESOURCE__RDFS_SEE_ALSO:
            getRDFSSeeAlso().clear();
            return;
        case RDFSPackage.RDFS_RESOURCE__RDF_TYPE:
            getRDFType().clear();
            return;
        case RDFSPackage.RDFS_RESOURCE__RDFS_MEMBER:
            getRDFSMember().clear();
            return;
        case RDFSPackage.RDFS_RESOURCE__PREDICATE_STATEMENT:
            getPredicateStatement().clear();
            return;
        case RDFSPackage.RDFS_RESOURCE__RDFS_COMMENT:
            getRDFSComment().clear();
            return;
        case RDFSPackage.RDFS_RESOURCE__RDFS_LABEL:
            getRDFSLabel().clear();
            return;
        case RDFSPackage.RDFS_RESOURCE__NAMESPACE:
            setNamespace((Namespace) null);
            return;
        }
        eDynamicUnset(eFeature);
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public boolean eIsSet(EStructuralFeature eFeature) {
        switch (eDerivedStructuralFeatureID(eFeature)) {
        case RDFSPackage.RDFS_RESOURCE__LOCAL_NAME:
            return LOCAL_NAME_EDEFAULT == null ? localName != null
                    : !LOCAL_NAME_EDEFAULT.equals(localName);
        case RDFSPackage.RDFS_RESOURCE__URI:
            return URI_EDEFAULT == null ? getURI() != null : !URI_EDEFAULT
                    .equals(getURI());
        case RDFSPackage.RDFS_RESOURCE__SUBJECT_STATEMENT:
            return subjectStatement != null && !subjectStatement.isEmpty();
        case RDFSPackage.RDFS_RESOURCE__OBJECT_STATEMENT:
            return objectStatement != null && !objectStatement.isEmpty();
        case RDFSPackage.RDFS_RESOURCE__RDFS_IS_DEFINED_BY:
            return rdfsIsDefinedBy != null && !rdfsIsDefinedBy.isEmpty();
        case RDFSPackage.RDFS_RESOURCE__RDF_VALUE:
            return rdfValue != null && !rdfValue.isEmpty();
        case RDFSPackage.RDFS_RESOURCE__RDFS_SEE_ALSO:
            return rdfsSeeAlso != null && !rdfsSeeAlso.isEmpty();
        case RDFSPackage.RDFS_RESOURCE__RDF_TYPE:
            return rdfType != null && !rdfType.isEmpty();
        case RDFSPackage.RDFS_RESOURCE__RDFS_MEMBER:
            return rdfsMember != null && !rdfsMember.isEmpty();
        case RDFSPackage.RDFS_RESOURCE__PREDICATE_STATEMENT:
            return predicateStatement != null && !predicateStatement.isEmpty();
        case RDFSPackage.RDFS_RESOURCE__RDFS_COMMENT:
            return rdfsComment != null && !rdfsComment.isEmpty();
        case RDFSPackage.RDFS_RESOURCE__RDFS_LABEL:
            return rdfsLabel != null && !rdfsLabel.isEmpty();
        case RDFSPackage.RDFS_RESOURCE__NAMESPACE:
            return namespace != null;
        }
        return eDynamicIsSet(eFeature);
    }

    /**
     * <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    public String toString() {
        if (eIsProxy())
            return super.toString();

        StringBuffer result = new StringBuffer(super.toString());
        result.append(" (localName: ");
        result.append(localName);
        result.append(')');
        return result.toString();
    }

    /* (non-Javadoc)
     * @see org.eclipse.rdfs.RDFSResource#addPropertyValue(org.eclipse.rdfs.RDFProperty, org.eclipse.rdfs.RDFSResource)
     */
    public boolean addPropertyValue(RDFProperty property, RDFSResource resource) {
        //if input params error
        if (property == null || resource == null)
            return false;

        //if value already exist
        List values = this.getPropertyValues(property);
        if (values != null)
            if (values.contains(resource))
                return false;

        //new statement
        RDFSFactory factory = RDFSFactory.eINSTANCE;
        factory.createRDFStatement((Ontology)this.eContainer(), this, property, resource);
        return true;        
    }

    /* (non-Javadoc)
     * @see org.eclipse.rdfs.RDFSResource#getPropertyValues(org.eclipse.rdfs.RDFProperty)
     */
    public List getPropertyValues(RDFProperty property) {
        //if input params error
        if (property == null)
            return null;

        Vector values = new Vector();
        RDFStatement resource = null;
        
        //iterate the statments that this RDFSResource act as subject
        for (Iterator iter = this.getSubjectStatement().iterator(); iter.hasNext();) {
            resource = (RDFStatement) iter.next();
            if (resource.getRDFPredicate().equals(property))
                //if subject and predicate match
                values.addElement(resource.getRDFObject());
        }

        return values;
    }
    
    /* (non-Javadoc)
     * @see org.eclipse.rdfs.RDFSResource#getPredicateStatement(boolean)
     */
    public EList getPredicateStatement(boolean bInference) {
        if (bInference) {
            return new BasicEList(((Ontology) this.eContainer()).getReasoner()
                    .getInferredStatements((RDFProperty) this));
        } else {
            return getPredicateStatement();
        }
    }

} //RDFSResourceImpl
