/**
 * <copyright> 
 * 
 * Copyright (c) 2004-2005 IBM Corporation and others. 
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License - v 1.0 
 * which accompanies this distribution, and is available at 
 * http://opensource.org/licenses/eclipse-1.0.txt 
 * 
 * Contributors: 
 *   IBM - Initial API and implementation 
 * 
 * </copyright> 
 *
 * $Id: RDFSSwitch.java,v 1.1.1.1 2006/01/31 09:13:25 gxie Exp $
 */
package org.eclipse.eodm.rdfs.util;

import java.util.List;

import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.eodm.rdfs.Namespace;
import org.eclipse.eodm.rdfs.Ontology;
import org.eclipse.eodm.rdfs.PlainLiteral;
import org.eclipse.eodm.rdfs.RDFAlt;
import org.eclipse.eodm.rdfs.RDFBag;
import org.eclipse.eodm.rdfs.RDFList;
import org.eclipse.eodm.rdfs.RDFProperty;
import org.eclipse.eodm.rdfs.RDFSClass;
import org.eclipse.eodm.rdfs.RDFSContainer;
import org.eclipse.eodm.rdfs.RDFSContainerMembershipProperty;
import org.eclipse.eodm.rdfs.RDFSDatatype;
import org.eclipse.eodm.rdfs.RDFSLiteral;
import org.eclipse.eodm.rdfs.RDFSPackage;
import org.eclipse.eodm.rdfs.RDFSResource;
import org.eclipse.eodm.rdfs.RDFSeq;
import org.eclipse.eodm.rdfs.RDFStatement;
import org.eclipse.eodm.rdfs.RDFXMLLiteral;
import org.eclipse.eodm.rdfs.TypedLiteral;

/**
 * <!-- begin-user-doc --> The <b>Switch </b> for the model's inheritance
 * hierarchy. It supports the call {@link #doSwitch(EObject) doSwitch(object)}
 * to invoke the <code>caseXXX</code> method for each class of the model,
 * starting with the actual class of the object and proceeding up the
 * inheritance hierarchy until a non-null result is returned, which is the
 * result of the switch. <!-- end-user-doc -->
 * 
 * @see org.eclipse.eodm.rdfs.RDFSPackage
 * @generated
 */
public class RDFSSwitch {
    /**
     * The cached model package <!-- begin-user-doc --> <!-- end-user-doc -->
     * 
     * @generated
     */
    protected static RDFSPackage modelPackage;

    /**
     * Creates an instance of the switch. <!-- begin-user-doc --> <!--
     * end-user-doc -->
     * 
     * @generated
     */
    public RDFSSwitch() {
        if (modelPackage == null) {
            modelPackage = RDFSPackage.eINSTANCE;
        }
    }

    /**
     * Calls <code>caseXXX</code> for each class of the model until one
     * returns a non null result; it yields that result. <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @return the first non-null result returned by a <code>caseXXX</code>
     *         call.
     * @generated
     */
    public Object doSwitch(EObject theEObject) {
        return doSwitch(theEObject.eClass(), theEObject);
    }

    /**
     * Calls <code>caseXXX</code> for each class of the model until one
     * returns a non null result; it yields that result. <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @return the first non-null result returned by a <code>caseXXX</code>
     *         call.
     * @generated
     */
    protected Object doSwitch(EClass theEClass, EObject theEObject) {
        if (theEClass.eContainer() == modelPackage) {
            return doSwitch(theEClass.getClassifierID(), theEObject);
        } else {
            List eSuperTypes = theEClass.getESuperTypes();
            return eSuperTypes.isEmpty() ? defaultCase(theEObject) : doSwitch(
                    (EClass) eSuperTypes.get(0), theEObject);
        }
    }

    /**
     * Calls <code>caseXXX</code> for each class of the model until one
     * returns a non null result; it yields that result. <!-- begin-user-doc -->
     * <!-- end-user-doc -->
     * 
     * @return the first non-null result returned by a <code>caseXXX</code>
     *         call.
     * @generated
     */
    protected Object doSwitch(int classifierID, EObject theEObject) {
        switch (classifierID) {
        case RDFSPackage.RDFS_RESOURCE: {
            RDFSResource rdfsResource = (RDFSResource) theEObject;
            Object result = caseRDFSResource(rdfsResource);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDFS_CLASS: {
            RDFSClass rdfsClass = (RDFSClass) theEObject;
            Object result = caseRDFSClass(rdfsClass);
            if (result == null)
                result = caseRDFSResource(rdfsClass);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDFS_LITERAL: {
            RDFSLiteral rdfsLiteral = (RDFSLiteral) theEObject;
            Object result = caseRDFSLiteral(rdfsLiteral);
            if (result == null)
                result = caseRDFSResource(rdfsLiteral);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDFS_DATATYPE: {
            RDFSDatatype rdfsDatatype = (RDFSDatatype) theEObject;
            Object result = caseRDFSDatatype(rdfsDatatype);
            if (result == null)
                result = caseRDFSClass(rdfsDatatype);
            if (result == null)
                result = caseRDFSResource(rdfsDatatype);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDFXML_LITERAL: {
            RDFXMLLiteral rdfxmlLiteral = (RDFXMLLiteral) theEObject;
            Object result = caseRDFXMLLiteral(rdfxmlLiteral);
            if (result == null)
                result = caseTypedLiteral(rdfxmlLiteral);
            if (result == null)
                result = caseRDFSLiteral(rdfxmlLiteral);
            if (result == null)
                result = caseRDFSResource(rdfxmlLiteral);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDF_PROPERTY: {
            RDFProperty rdfProperty = (RDFProperty) theEObject;
            Object result = caseRDFProperty(rdfProperty);
            if (result == null)
                result = caseRDFSResource(rdfProperty);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDF_LIST: {
            RDFList rdfList = (RDFList) theEObject;
            Object result = caseRDFList(rdfList);
            if (result == null)
                result = caseRDFSResource(rdfList);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDFS_CONTAINER: {
            RDFSContainer rdfsContainer = (RDFSContainer) theEObject;
            Object result = caseRDFSContainer(rdfsContainer);
            if (result == null)
                result = caseRDFSResource(rdfsContainer);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDF_ALT: {
            RDFAlt rdfAlt = (RDFAlt) theEObject;
            Object result = caseRDFAlt(rdfAlt);
            if (result == null)
                result = caseRDFSContainer(rdfAlt);
            if (result == null)
                result = caseRDFSResource(rdfAlt);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDF_BAG: {
            RDFBag rdfBag = (RDFBag) theEObject;
            Object result = caseRDFBag(rdfBag);
            if (result == null)
                result = caseRDFSContainer(rdfBag);
            if (result == null)
                result = caseRDFSResource(rdfBag);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDFS_EQ: {
            RDFSeq rdfSeq = (RDFSeq) theEObject;
            Object result = caseRDFSeq(rdfSeq);
            if (result == null)
                result = caseRDFSContainer(rdfSeq);
            if (result == null)
                result = caseRDFSResource(rdfSeq);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDFS_CONTAINER_MEMBERSHIP_PROPERTY: {
            RDFSContainerMembershipProperty rdfsContainerMembershipProperty = (RDFSContainerMembershipProperty) theEObject;
            Object result = caseRDFSContainerMembershipProperty(rdfsContainerMembershipProperty);
            if (result == null)
                result = caseRDFProperty(rdfsContainerMembershipProperty);
            if (result == null)
                result = caseRDFSResource(rdfsContainerMembershipProperty);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.RDFS_TATEMENT: {
            RDFStatement rdfStatement = (RDFStatement) theEObject;
            Object result = caseRDFStatement(rdfStatement);
            if (result == null)
                result = caseRDFSResource(rdfStatement);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.ONTOLOGY: {
            Ontology ontology = (Ontology) theEObject;
            Object result = caseOntology(ontology);
            if (result == null)
                result = caseRDFSResource(ontology);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.PLAIN_LITERAL: {
            PlainLiteral plainLiteral = (PlainLiteral) theEObject;
            Object result = casePlainLiteral(plainLiteral);
            if (result == null)
                result = caseRDFSLiteral(plainLiteral);
            if (result == null)
                result = caseRDFSResource(plainLiteral);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.TYPED_LITERAL: {
            TypedLiteral typedLiteral = (TypedLiteral) theEObject;
            Object result = caseTypedLiteral(typedLiteral);
            if (result == null)
                result = caseRDFSLiteral(typedLiteral);
            if (result == null)
                result = caseRDFSResource(typedLiteral);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        case RDFSPackage.NAMESPACE: {
            Namespace namespace = (Namespace) theEObject;
            Object result = caseNamespace(namespace);
            if (result == null)
                result = defaultCase(theEObject);
            return result;
        }
        default:
            return defaultCase(theEObject);
        }
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>Resource</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>Resource</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFSResource(RDFSResource object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>Class</em>'. <!-- begin-user-doc --> This implementation returns
     * null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>Class</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFSClass(RDFSClass object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>Literal</em>'. <!-- begin-user-doc --> This implementation returns
     * null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>Literal</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFSLiteral(RDFSLiteral object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>Datatype</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>Datatype</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFSDatatype(RDFSDatatype object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>RDFXML Literal</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>RDFXML Literal</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFXMLLiteral(RDFXMLLiteral object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>RDF Property</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>RDF Property</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFProperty(RDFProperty object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>RDF List</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>RDF List</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFList(RDFList object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>Container</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>Container</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFSContainer(RDFSContainer object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>RDF Alt</em>'. <!-- begin-user-doc --> This implementation returns
     * null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>RDF Alt</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFAlt(RDFAlt object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>RDF Bag</em>'. <!-- begin-user-doc --> This implementation returns
     * null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>RDF Bag</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFBag(RDFBag object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>eq</em>'. <!-- begin-user-doc --> This implementation returns
     * null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>eq</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFSeq(RDFSeq object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>Container Membership Property</em>'. <!-- begin-user-doc --> This
     * implementation returns null; returning a non-null result will terminate
     * the switch. <!-- end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>Container Membership Property</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFSContainerMembershipProperty(
            RDFSContainerMembershipProperty object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>tatement</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>tatement</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseRDFStatement(RDFStatement object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>Ontology</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>Ontology</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseOntology(Ontology object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>Plain Literal</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>Plain Literal</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object casePlainLiteral(PlainLiteral object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>Typed Literal</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>Typed Literal</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseTypedLiteral(TypedLiteral object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>Namespace</em>'. <!-- begin-user-doc --> This implementation
     * returns null; returning a non-null result will terminate the switch. <!--
     * end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>Namespace</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
     * @generated
     */
    public Object caseNamespace(Namespace object) {
        return null;
    }

    /**
     * Returns the result of interpretting the object as an instance of '
     * <em>EObject</em>'. <!-- begin-user-doc --> This implementation returns
     * null; returning a non-null result will terminate the switch, but this is
     * the last case anyway. <!-- end-user-doc -->
     * 
     * @param object
     *            the target of the switch.
     * @return the result of interpretting the object as an instance of '
     *         <em>EObject</em>'.
     * @see #doSwitch(org.eclipse.emf.ecore.EObject)
     * @generated
     */
    public Object defaultCase(EObject object) {
        return null;
    }

} //RdfsSwitch
